@@ -21,13 +21,16 @@ package org.apache.ranger.plugin.policyengine;
 
 import org.apache.ranger.plugin.contextenricher.RangerTagForEval;
 import org.apache.ranger.plugin.policyevaluator.RangerPolicyEvaluator;
+import org.apache.ranger.plugin.policyresourcematcher.RangerPolicyResourceMatcher;
 
 import java.io.Serializable;
 import java.util.Comparator;
 
+
 public class PolicyEvaluatorForTag {
 	public static final Comparator<PolicyEvaluatorForTag> EVAL_ORDER_COMPARATOR = new PolicyEvalOrderComparator();
 	public static final Comparator<PolicyEvaluatorForTag> NAME_COMPARATOR       = new PolicyNameComparator();
+	public static final Comparator<PolicyEvaluatorForTag> MATCH_TYPE_COMPARATOR = new MatchTypeComparator();
 
 	private final RangerPolicyEvaluator evaluator;
 	private final RangerTagForEval      tag;
@@ -58,4 +61,17 @@ public class PolicyEvaluatorForTag {
 			return RangerPolicyEvaluator.EVAL_ORDER_COMPARATOR.compare(me.getEvaluator(), other.getEvaluator());
 		}
 	}
+
+	static class MatchTypeComparator implements Comparator<PolicyEvaluatorForTag>, Serializable {
+		@Override
+		public int compare(PolicyEvaluatorForTag me, PolicyEvaluatorForTag other) {
+			int ret = RangerPolicyResourceMatcher.MATCH_TYPE_COMPARATOR.compare(me.getTag().getMatchType(), other.getTag().getMatchType());
+
+			if (ret == 0) {
+				ret = RangerPolicyEvaluator.NAME_COMPARATOR.compare(me.getEvaluator(), other.getEvaluator());
+			}
+
+			return ret;
+		}
+	}
 }
