@@ -29,6 +29,7 @@ import org.apache.ranger.authorization.utils.StringUtil;
 import org.apache.ranger.plugin.contextenricher.RangerTagForEval;
 import org.apache.ranger.plugin.model.RangerPolicy;
 import org.apache.ranger.plugin.model.RangerServiceDef;
+import org.apache.ranger.plugin.model.validation.RangerServiceDefHelper;
 import org.apache.ranger.plugin.policyevaluator.RangerPolicyEvaluator;
 import org.apache.ranger.plugin.policyresourcematcher.RangerPolicyResourceMatcher.MatchType;
 import org.apache.ranger.plugin.service.RangerDefaultRequestProcessor;
@@ -51,6 +52,7 @@ import java.util.HashSet;
 import java.util.List;
 import java.util.Map;
 import java.util.Set;
+import java.util.stream.Collectors;
 
 import static org.apache.ranger.plugin.policyengine.PolicyEvaluatorForTag.MATCH_TYPE_COMPARATOR;
 
@@ -376,6 +378,23 @@ public class RangerPolicyEngineImpl implements RangerPolicyEngine {
 		return ret;
 	}
 
+   @Override
+   public RangerServiceDefHelper getServiceDefHelper() {
+	   final RangerServiceDefHelper ret;
+
+	   try (RangerReadWriteLock.RangerLock readLock = policyEngine.getReadLock()) {
+		   if (LOG.isDebugEnabled()) {
+			   if (readLock.isLockingEnabled()) {
+						   LOG.debug("Acquired lock - " + readLock);
+			   }
+		   }
+
+		   ret = policyEngine.getServiceDefHelper();
+	   }
+
+	   return ret;
+	}
+
 	@Override
 	public long getPolicyVersion() {
 		long ret;
@@ -668,15 +687,13 @@ public class RangerPolicyEngineImpl implements RangerPolicyEngine {
 		final RangerAccessResult ret;
 
 		if (request.isAccessTypeAny()) {
-			List<RangerServiceDef.RangerAccessTypeDef> allAccessDefs = getServiceDef().getAccessTypes();
-
-			Set<String> allRequestedAccesses = new HashSet<>();
-			for (RangerServiceDef.RangerAccessTypeDef accessTypeDef : allAccessDefs) {
-				String requestedAccess = accessTypeDef.getName();
-				allRequestedAccesses.add(requestedAccess);
-			}
+			Set<String> allRequestedAccesses = getServiceDefHelper().getAllAccessTypes();
 			RangerAccessRequestUtil.setAllRequestedAccessTypes(request.getContext(), allRequestedAccesses);
 			RangerAccessRequestUtil.setIsAnyAccessInContext(request.getContext(), Boolean.TRUE);
+			if (!request.ignoreDescendantDeny()) {
+				Set<Set<String>> accessGroups = allRequestedAccesses.stream().map(Collections::singleton).collect(Collectors.toSet());
+				RangerAccessRequestUtil.setAllRequestedAccessTypeGroups(request, accessGroups);
+			}
 		}
 
 		ret = evaluatePoliciesForOneAccessTypeNoAudit(request, policyType, zoneName, policyRepository, tagPolicyRepository);
