@@ -21,6 +21,7 @@ package org.apache.ranger.plugin.policyengine;
 
 
 import org.apache.commons.collections.CollectionUtils;
+import org.apache.commons.collections.Predicate;
 import org.apache.commons.lang.StringUtils;
 import org.apache.hadoop.conf.Configuration;
 import org.apache.ranger.plugin.model.RangerPolicy.RangerPolicyResource;
@@ -36,16 +37,7 @@ import org.apache.ranger.plugin.util.ServiceDefUtil;
 import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
 
-import java.util.ArrayList;
-import java.util.Arrays;
-import java.util.Collection;
-import java.util.Collections;
-import java.util.HashMap;
-import java.util.HashSet;
-import java.util.List;
-import java.util.Map;
-import java.util.Set;
-import java.util.Stack;
+import java.util.*;
 import java.util.concurrent.BlockingQueue;
 import java.util.concurrent.LinkedBlockingQueue;
 
@@ -190,29 +182,44 @@ public class RangerResourceTrie<T extends RangerResourceEvaluator> {
         }
     }
 
-    public Set<T> getInheritedEvaluators() {
-        return inheritedEvaluators;
-    }
-
     public Set<T> getEvaluatorsForResource(Object resource) {
         return getEvaluatorsForResource(resource, ResourceElementMatchingScope.SELF);
     }
 
-    @SuppressWarnings("unchecked")
     public Set<T> getEvaluatorsForResource(Object resource, ResourceElementMatchingScope scope) {
-        if (resource instanceof String) {
-            return getEvaluatorsForResource((String) resource, scope);
-        } else if (resource instanceof Collection) {
-            Collection<String> resources = (Collection<String>) resource;
+        return getEvaluatorsForResource(resource, scope, (Predicate) null);
+    }
 
-            if (CollectionUtils.isEmpty(resources)) {  // treat empty collection same as empty-string
-                return getEvaluatorsForResource("", scope);
-            } else {
-                return getEvaluatorsForResources(resources, scope);
-            }
-        }
+    public Set<T> getEvaluatorsForResource(Object resource, ResourceElementMatchingScope scope, Predicate predicate) {
+        EvalCollector<T> ret = new EvalCollector<>(predicate);
 
-        return null;
+        traverse(resource, scope, ret);
+
+        return ret.getResult();
+    }
+
+    public Set<T> getEvaluatorsForResource(Object resource, ResourceElementMatchingScope scope, Set<T> filter) {
+        return getEvaluatorsForResource(resource, scope, filter, null);
+    }
+
+    public Set<T> getEvaluatorsForResource(Object resource, ResourceElementMatchingScope scope, Set<T> filter, Predicate predicate) {
+        EvalSubsetCollector<T> ret = new EvalSubsetCollector<>(filter, predicate);
+
+        traverse(resource, scope, ret);
+
+        return ret.getResult();
+    }
+
+    public int getEvaluatorsCountForResource(Object resource, ResourceElementMatchingScope scope) {
+        return getEvaluatorsCountForResource(resource, scope, null);
+    }
+
+    public int getEvaluatorsCountForResource(Object resource, ResourceElementMatchingScope scope, Predicate predicate) {
+        EvalCountCollector<T> ret = new EvalCountCollector<>(predicate);
+
+        traverse(resource, scope, ret);
+
+        return ret.getResult();
     }
 
     public void add(RangerPolicyResource resource, T evaluator) {
@@ -594,19 +601,38 @@ public class RangerResourceTrie<T extends RangerResourceEvaluator> {
         int prefixLen = getNonWildcardPrefixLength(str);
 
         return (prefixLen < str.length()) ? str.substring(0, prefixLen) : str;
+
     }
 
+    public void traverse(Object resource, ResourceElementMatchingScope scope, TraverseMatchHandler<T> handler) {
+        if (resource instanceof String) {
+            traverse((String) resource, scope, handler);
+        } else if (resource instanceof Collection) {
+            Collection<String> resources = (Collection<String>) resource;
 
+            if (CollectionUtils.isEmpty(resources)) {  // treat empty collection same as empty-string
+                traverse("", scope, handler);
+            } else {
+                traverse(resources, scope, handler);
+            }
+        }
+    }
 
-    private Set<T> getEvaluatorsForResource(String resource, ResourceElementMatchingScope scope) {
+    public void traverse(Collection<String> resources, ResourceElementMatchingScope scope, TraverseMatchHandler<T> handler) {
+        for (String resource : resources) {
+            traverse(resource, scope, handler);
+        }
+    }
+
+    public void traverse(String resource, ResourceElementMatchingScope scope, TraverseMatchHandler<T> handler) {
         if(LOG.isDebugEnabled()) {
-            LOG.debug("==> RangerResourceTrie.getEvaluatorsForResource(" + resource + ", " + scope + ")");
+            LOG.debug("==> RangerResourceTrie.traverse(" + resource + ", " + scope + ")");
         }
 
         RangerPerfTracer perf = null;
 
         if(RangerPerfTracer.isPerfTraceEnabled(PERF_TRIE_OP_LOG)) {
-            perf = RangerPerfTracer.getPerfTracer(PERF_TRIE_OP_LOG, "RangerResourceTrie.getEvaluatorsForResource(resource=" + resource + ")");
+            perf = RangerPerfTracer.getPerfTracer(PERF_TRIE_OP_LOG, "RangerResourceTrie.traverse(resource=" + resource + ")");
         }
 
         TrieNode<T> curr   = root;
@@ -615,14 +641,14 @@ public class RangerResourceTrie<T extends RangerResourceEvaluator> {
         final int   len    = resource.length();
         int         i      = 0;
 
-        Set<T>      accumulatedEvaluators = new HashSet<>();
+        handler.process(inheritedEvaluators);
 
         while (i < len) {
             if (!isOptimizedForSpace) {
                 curr.setupIfNeeded(parent);
             } else {
-                if (curr.getWildcardEvaluators() != null) {
-                    accumulatedEvaluators.addAll(curr.getWildcardEvaluators());
+                if (handler.process(curr.getWildcardEvaluators())) {
+                    break;
                 }
             }
 
@@ -646,39 +672,30 @@ public class RangerResourceTrie<T extends RangerResourceEvaluator> {
         if (!isOptimizedForSpace) {
             curr.setupIfNeeded(parent);
         } else {
-            if (curr.getWildcardEvaluators() != null) {
-                accumulatedEvaluators.addAll(curr.getWildcardEvaluators());
-            }
+            handler.process(curr.getWildcardEvaluators());
         }
 
         boolean isSelfMatch = (i == len);
-        Set<T>  ret;
 
         if (!isOptimizedForSpace) {
-            ret = isSelfMatch ? curr.getEvaluators() : curr.getWildcardEvaluators();
+            handler.process(isSelfMatch ? curr.getEvaluators() : curr.getWildcardEvaluators());
         } else {
             if (isSelfMatch) {
-                if (curr.getEvaluators() != null) {
-                    accumulatedEvaluators.addAll(curr.getEvaluators());
-                }
+                handler.process(curr.getEvaluators());
             }
-            ret = accumulatedEvaluators;
         }
 
-        final boolean includeChildEvaluators = scope == ResourceElementMatchingScope.SELF_OR_CHILD || scope == ResourceElementMatchingScope.SELF_OR_PREFIX;
-        final Set<T>  childEvaluators        = includeChildEvaluators ? new HashSet<>() : null;
-
         if (scope == ResourceElementMatchingScope.SELF_OR_CHILD) {
             final boolean resourceEndsWithSep = resource.charAt(resource.length() - 1) == separatorChar;
 
             if (isSelfMatch) { // resource == path(curr)
                 if (resourceEndsWithSep) { // ex: resource=/tmp/
-                    curr.getChildren().values().stream().forEach(c -> c.collectChildEvaluators(separatorChar, 0, childEvaluators));
+                    curr.getChildren().values().forEach(c -> c.collectChildEvaluators(separatorChar, 0, handler));
                 } else { // ex: resource=/tmp
                     curr = curr.getChild(separatorChar);
 
                     if (curr != null) {
-                        curr.collectChildEvaluators(separatorChar, 1, childEvaluators);
+                        curr.collectChildEvaluators(separatorChar, 1, handler);
                     }
                 }
             } else if (child != null) { // resource != path(child) ex: (resource=/tmp, path(child)=/tmp/test.txt or path(child)=/tmpdir)
@@ -687,31 +704,21 @@ public class RangerResourceTrie<T extends RangerResourceEvaluator> {
 
                 if (isPrefixMatch) {
                     if (resourceEndsWithSep) { // ex: resource=/tmp/
-                        child.collectChildEvaluators(separatorChar, remainingLen, childEvaluators);
+                        child.collectChildEvaluators(separatorChar, remainingLen, handler);
                     } else if (child.getStr().charAt(remainingLen) == separatorChar) { //  ex: resource=/tmp
-                        child.collectChildEvaluators(separatorChar, remainingLen + 1, childEvaluators);
+                        child.collectChildEvaluators(separatorChar, remainingLen + 1, handler);
                     }
                 }
             }
         } else if (scope == ResourceElementMatchingScope.SELF_OR_PREFIX) {
-            curr.collectChildEvaluators(resource, i, childEvaluators);
-        }
-
-        if (CollectionUtils.isNotEmpty(childEvaluators)) {
-            if (CollectionUtils.isNotEmpty(ret)) {
-                childEvaluators.addAll(ret);
-            }
-
-            ret = childEvaluators;
+            curr.collectChildEvaluators(resource, i, handler);
         }
 
         RangerPerfTracer.logAlways(perf);
 
         if(LOG.isDebugEnabled()) {
-            LOG.debug("<== RangerResourceTrie.getEvaluatorsForResource(" + resource + ", " + scope + "): evaluators=" + (ret == null ? null : Arrays.deepToString(ret.toArray())));
+            LOG.debug("<== RangerResourceTrie.traverse(" + resource + ", " + scope + "): evaluators=" + handler);
         }
-
-        return ret;
     }
 
     private TrieNode<T> getNodeForResource(String resource) {
@@ -757,53 +764,6 @@ public class RangerResourceTrie<T extends RangerResourceEvaluator> {
         return curr;
     }
 
-    private Set<T> getEvaluatorsForResources(Collection<String> resources, ResourceElementMatchingScope scope) {
-        if(LOG.isDebugEnabled()) {
-            LOG.debug("==> RangerResourceTrie.getEvaluatorsForResources(" + resources + ")");
-        }
-
-        Set<T>       ret           = null;
-        Map<Long, T> evaluatorsMap = null;
-
-        for (String resource : resources) {
-            Set<T> resourceEvaluators = getEvaluatorsForResource(resource, scope);
-
-            if (CollectionUtils.isEmpty(resourceEvaluators)) {
-                continue;
-            }
-
-            if (evaluatorsMap == null) {
-                if (ret == null) { // first resource: don't create map yet
-                    ret = resourceEvaluators;
-                } else if (ret != resourceEvaluators) { // if evaluator list is same as earlier resources, retain the list, else create a map
-                    evaluatorsMap = new HashMap<>();
-
-                    for (T evaluator : ret) {
-                        evaluatorsMap.put(evaluator.getId(), evaluator);
-                    }
-
-                    ret = null;
-                }
-            }
-
-            if (evaluatorsMap != null) {
-                for (T evaluator : resourceEvaluators) {
-                    evaluatorsMap.put(evaluator.getId(), evaluator);
-                }
-            }
-        }
-
-        if (ret == null && evaluatorsMap != null) {
-            ret = new HashSet<>(evaluatorsMap.values());
-        }
-
-        if(LOG.isDebugEnabled()) {
-            LOG.debug("<== RangerResourceTrie.getEvaluatorsForResources(" + resources + "): evaluatorCount=" + (ret == null ? 0 : ret.size()));
-        }
-
-        return ret;
-    }
-
     @Override
     public String toString() {
         StringBuilder sb = new StringBuilder();
@@ -1141,14 +1101,14 @@ public class RangerResourceTrie<T extends RangerResourceEvaluator> {
             if (LOG.isDebugEnabled()) {
                 LOG.debug("==> removeSelfFromTrie(" + this + ")");
             }
-            if (evaluators == null && children.size() == 0) {
+            if (evaluators == null && wildcardEvaluators == null && children.size() == 0) {
                 TrieNode<U> parent = getParent();
                 if (parent != null) {
                     parent.children.remove(str.charAt(0));
                 }
             } else {
                 if (LOG.isDebugEnabled()) {
-                    LOG.debug("removeSelfFromTrie(" + this + ") could not remove self from Trie");
+                    LOG.debug("removeSelfFromTrie(" + this + "): node is not removed from Trie : [evaluators:" + evaluators + ", wildcard-evaluators:" + wildcardEvaluators + ", number-of-children-nodes:" + children.size() + "]");
                 }
             }
             if (LOG.isDebugEnabled()) {
@@ -1229,7 +1189,7 @@ public class RangerResourceTrie<T extends RangerResourceEvaluator> {
             }
         }
 
-        void collectChildEvaluators(Character sep, int startIdx, Set<U> childEvaluators) {
+        void collectChildEvaluators(Character sep, int startIdx, TraverseMatchHandler<U> handler) {
             if (!isOptimizedForSpace) {
                 setupIfNeeded(getParent());
             }
@@ -1238,30 +1198,24 @@ public class RangerResourceTrie<T extends RangerResourceEvaluator> {
 
             if (sepPos == -1) { // ex: startIdx=5, path(str)=/tmp/test, path(a child) could be: /tmp/test.txt, /tmp/test/, /tmp/test/a, /tmp/test/a/b
                 if (isOptimizedForSpace) {
-                    if (this.wildcardEvaluators != null) {
-                        childEvaluators.addAll(this.wildcardEvaluators);
-                    }
-                }
-                if (this.evaluators != null) {
-                    childEvaluators.addAll(this.evaluators);
+                    handler.process(this.wildcardEvaluators);
                 }
 
-                children.values().stream().forEach(c -> c.collectChildEvaluators(sep, 0, childEvaluators));
+                handler.process(this.evaluators);
+
+                children.values().forEach(c -> c.collectChildEvaluators(sep, 0, handler));
             } else if (sepPos == (str.length() - 1)) { // ex: str=/tmp/test/, startIdx=5
                 if (isOptimizedForSpace) {
-                    if (this.wildcardEvaluators != null) {
-                        childEvaluators.addAll(this.wildcardEvaluators);
-                    }
-                }
-                if (this.evaluators != null) {
-                    childEvaluators.addAll(this.evaluators);
+                    handler.process(this.wildcardEvaluators);
                 }
+
+                handler.process(this.evaluators);
             }
         }
 
-        void collectChildEvaluators(String resource, int startIndex, Set<U> childEvaluators) {
+        void collectChildEvaluators(String resource, int startIndex, TraverseMatchHandler<U> handler) {
             if (startIndex == resource.length()) {
-                collectChildEvaluators(childEvaluators);
+                collectChildEvaluators(handler);
             } else if (startIndex < resource.length()) {
                 Character   startChar = getLookupChar(resource, startIndex);
                 TrieNode<U> childNode = children.get(startChar);
@@ -1275,25 +1229,20 @@ public class RangerResourceTrie<T extends RangerResourceEvaluator> {
                     int lenToMatch = Math.min(resource.length() - startIndex, childStr.length());
 
                     if (resource.regionMatches(optIgnoreCase, startIndex, childStr, 0, lenToMatch)) {
-                        if (childNode.wildcardEvaluators != null) {
-                            childEvaluators.addAll(childNode.wildcardEvaluators);
-                        }
-
-                        if (childNode.evaluators != null) {
-                            childEvaluators.addAll(childNode.evaluators);
-                        }
+                        handler.process(childNode.wildcardEvaluators);
+                        handler.process(childNode.evaluators);
 
                         if (resource.length() == (startIndex + lenToMatch)) {
-                            childNode.collectChildEvaluators(childEvaluators);
+                            childNode.collectChildEvaluators(handler);
                         } else {
-                            childNode.children.values().stream().forEach(c -> c.collectChildEvaluators(resource, startIndex + childStr.length(), childEvaluators));
+                            childNode.children.values().forEach(c -> c.collectChildEvaluators(resource, startIndex + childStr.length(), handler));
                         }
                     }
                 }
             }
         }
 
-        private void collectChildEvaluators(Set<U> childEvaluators) {
+        private void collectChildEvaluators(TraverseMatchHandler<U> childEvaluators) {
             Stack<TrieNode<U>> nodes = new Stack<>();
 
             nodes.addAll(children.values());
@@ -1305,13 +1254,8 @@ public class RangerResourceTrie<T extends RangerResourceEvaluator> {
                     childNode.setupIfNeeded(childNode.getParent());
                 }
 
-                if (childNode.wildcardEvaluators != null) {
-                    childEvaluators.addAll(childNode.wildcardEvaluators);
-                }
-
-                if (childNode.evaluators != null) {
-                    childEvaluators.addAll(childNode.evaluators);
-                }
+                childEvaluators.process(childNode.wildcardEvaluators);
+                childEvaluators.process(childNode.evaluators);
 
                 nodes.addAll(childNode.children.values());
             }
@@ -1381,4 +1325,133 @@ public class RangerResourceTrie<T extends RangerResourceEvaluator> {
             }
         }
     }
+
+    public interface TraverseMatchHandler<T extends RangerResourceEvaluator> {
+        // return: true  - stop traverse, processing is complete
+        //         false - continue traverse, processing is not complete yet
+        boolean process(Set<T> evaluators);
+    }
+
+    public static class EvalCollector<T extends RangerResourceEvaluator> implements TraverseMatchHandler<T> {
+        private final Predicate predicate;
+        private       Set<T>    result;
+        private       boolean   isOwnedResult = false;
+
+        public EvalCollector(Predicate predicate) {
+            this.predicate = predicate;
+            this.result    = null;
+        }
+
+        public Set<T> getResult() {
+            return result;
+        }
+
+        @Override
+        public boolean process(Set<T> evaluators) {
+            if (evaluators != null && !evaluators.isEmpty()) {
+                if (result == null) {
+                    if (predicate == null) {
+                        result = evaluators;
+                    } else {
+                        result = new HashSet<>();
+                        isOwnedResult = true;
+
+                        for (T evaluator : evaluators) {
+                            if (predicate.evaluate(evaluator)) {
+                                result.add(evaluator);
+                            }
+                        }
+                    }
+                } else {
+                    if (!isOwnedResult) {
+                        result = new HashSet<>(result);
+
+                        isOwnedResult = true;
+                    }
+
+                    if (predicate == null) {
+                        result.addAll(evaluators);
+                    } else {
+                        for (T evaluator : evaluators) {
+                            if (predicate.evaluate(evaluator)) {
+                                result.add(evaluator);
+                            }
+                        }
+                    }
+                }
+            }
+
+            return false; // continue traverse
+        }
+    }
+
+    public static class EvalSubsetCollector<T extends RangerResourceEvaluator> implements TraverseMatchHandler<T> {
+        private final Predicate predicate;
+        private final Set<T>    filter;
+        private       Set<T>    result;
+
+        public EvalSubsetCollector(Set<T> filter, Predicate predicate) {
+            this.predicate = predicate;
+            this.filter    = filter == null ? Collections.emptySet() : filter;
+            this.result    = null;
+        }
+
+        public Set<T> getResult() {
+            return result;
+        }
+
+        @Override
+        public boolean process(Set<T> evaluators) {
+            if (evaluators != null && !evaluators.isEmpty()) {
+                if (result == null) {
+                    result = new HashSet<>();
+                }
+
+                intersect(filter, evaluators, result);
+
+                if (predicate != null) {
+                    result.removeIf(evaluator -> !predicate.evaluate(evaluator));
+                }
+            }
+
+            return result != null && (filter.size() == result.size()); // stop traverse once the result includes all entries in the filter
+        }
+
+        private static <T> void intersect(Set<T> a, Set<T> b, Set<T> result) {
+            Set<T> smaller = a.size() < b.size() ? a : b;
+            Set<T> larger  = smaller == a ? b : a;
+
+            smaller.forEach(item -> { if (larger.contains(item)) result.add(item);  });
+        }
+    }
+
+    public static class EvalCountCollector<T extends RangerResourceEvaluator> implements TraverseMatchHandler<T> {
+        private final Predicate predicate;
+        private       int       result = 0;
+
+        public EvalCountCollector(Predicate predicate) {
+            this.predicate = predicate;
+        }
+
+        public int getResult() {
+            return result;
+        }
+
+        @Override
+        public boolean process(Set<T> evaluators) {
+            if (evaluators != null) {
+                if (predicate == null) {
+                    result += evaluators.size();
+                } else {
+                    for (T evaluator : evaluators) {
+                        if (predicate.evaluate(evaluator)) {
+                            result++;
+                        }
+                    }
+                }
+            }
+
+            return false; // continue traverse
+        }
+    }
 }
