@@ -20,6 +20,7 @@
 package org.apache.ranger.plugin.policyevaluator;
 
 import org.apache.commons.collections.CollectionUtils;
+import org.apache.commons.lang.StringUtils;
 import org.apache.ranger.plugin.model.RangerPolicy;
 import org.apache.ranger.plugin.model.RangerPolicy.RangerPolicyItemDataMaskInfo;
 import org.apache.ranger.plugin.model.RangerPolicy.RangerPolicyResource;
@@ -307,8 +308,10 @@ public abstract class RangerAbstractPolicyEvaluator implements RangerPolicyEvalu
 	private boolean isMatch(MatchType matchType, ResourceMatchingScope matchingScope) {
 		final boolean ret;
 
+		matchingScope = matchingScope != null ? matchingScope : ResourceMatchingScope.SELF;
+
 		if (matchingScope == ResourceMatchingScope.SELF_OR_DESCENDANTS) {
-			ret = matchType != MatchType.NONE;
+			ret = matchType == MatchType.SELF || matchType == MatchType.SELF_AND_ALL_DESCENDANTS || matchType == MatchType.DESCENDANT;
 		} else {
 			ret = matchType == MatchType.SELF || matchType == MatchType.SELF_AND_ALL_DESCENDANTS;
 		}
@@ -542,6 +545,7 @@ public abstract class RangerAbstractPolicyEvaluator implements RangerPolicyEvalu
 			this.resourceMatcher.setPolicyResources(resource, policyType);
 			this.resourceMatcher.setServiceDef(serviceDef);
 			this.resourceMatcher.setServiceDefHelper(serviceDefHelper);
+			this.resourceMatcher.setPluginContext(pluginContext);
 			this.resourceMatcher.init();
 		}
 
@@ -608,5 +612,8 @@ public abstract class RangerAbstractPolicyEvaluator implements RangerPolicyEvalu
 				return ServiceDefUtil.isAncestorOf(serviceDef, leafResourceDef, resourceDef);
 			}
 		}
+
+		@Override
+		public boolean isLeaf(String resourceName) { return StringUtils.equals(resourceName, leafResourceDef.getName()); }
 	}
 }
