@@ -220,23 +220,19 @@ public class RangerDefaultPolicyEvaluator extends RangerAbstractPolicyEvaluator
 				RangerPolicyResourceMatcher resourceMatcher = resourceEvaluator.getPolicyResourceMatcher();
 
 				if (!result.getIsAccessDetermined() || !result.getIsAuditedDetermined()) {
-					RangerPolicyResourceMatcher.MatchType matchType;
+					final RangerPolicyResourceMatcher.MatchType matchType;
 
-					if (RangerTagAccessRequest.class.isInstance(request)) {
+					if (request instanceof RangerTagAccessRequest) {
 						matchType = ((RangerTagAccessRequest) request).getMatchType();
-						if (matchType == RangerPolicyResourceMatcher.MatchType.ANCESTOR) {
-							matchType = RangerPolicyResourceMatcher.MatchType.SELF;
-						}
 					} else {
 						matchType = resourceMatcher != null ? resourceMatcher.getMatchType(request.getResource(), request.getResourceElementMatchingScopes(), request.getContext()) : RangerPolicyResourceMatcher.MatchType.NONE;
 					}
 
-					final boolean isMatched;
+					final RangerAccessRequest.ResourceMatchingScope resourceMatchingScope = request.getResourceMatchingScope() != null ? request.getResourceMatchingScope() : RangerAccessRequest.ResourceMatchingScope.SELF;
+					final boolean                                   isMatched;
 
-					if (request.isAccessTypeAny()) {
-						isMatched = matchType != RangerPolicyResourceMatcher.MatchType.NONE;
-					} else if (request.getResourceMatchingScope() == RangerAccessRequest.ResourceMatchingScope.SELF_OR_DESCENDANTS) {
-						isMatched = matchType != RangerPolicyResourceMatcher.MatchType.NONE;
+					if (request.isAccessTypeAny() || resourceMatchingScope == RangerAccessRequest.ResourceMatchingScope.SELF_OR_DESCENDANTS) {
+						isMatched = matchType == RangerPolicyResourceMatcher.MatchType.SELF || matchType == RangerPolicyResourceMatcher.MatchType.SELF_AND_ALL_DESCENDANTS || matchType == RangerPolicyResourceMatcher.MatchType.DESCENDANT;
 					} else {
 						isMatched = matchType == RangerPolicyResourceMatcher.MatchType.SELF || matchType == RangerPolicyResourceMatcher.MatchType.SELF_AND_ALL_DESCENDANTS;
 					}
@@ -539,7 +535,7 @@ public class RangerDefaultPolicyEvaluator extends RangerAbstractPolicyEvaluator
 			LOG.debug("==> RangerDefaultPolicyEvaluator.updateAccessResult(" + result + ", " + matchType +", " + isAllowed + ", " + reason + ", " + getPolicyId() + ")");
 		}
 		if (!isAllowed) {
-			if (matchType != RangerPolicyResourceMatcher.MatchType.DESCENDANT) {
+			if (matchType != RangerPolicyResourceMatcher.MatchType.DESCENDANT || !result.getAccessRequest().ignoreDescendantDeny()) {
 				result.setIsAllowed(false);
 				result.setPolicyPriority(getPolicyPriority());
 				result.setPolicyId(getPolicyId());
@@ -548,13 +544,11 @@ public class RangerDefaultPolicyEvaluator extends RangerAbstractPolicyEvaluator
 			}
 		} else {
 			if (!result.getIsAllowed()) { // if access is not yet allowed by another policy
-				if (matchType != RangerPolicyResourceMatcher.MatchType.ANCESTOR) {
-					result.setIsAllowed(true);
-					result.setPolicyPriority(getPolicyPriority());
-					result.setPolicyId(getPolicyId());
-					result.setReason(reason);
-					result.setPolicyVersion(getPolicy().getVersion());
-				}
+				result.setIsAllowed(true);
+				result.setPolicyPriority(getPolicyPriority());
+				result.setPolicyId(getPolicyId());
+				result.setReason(reason);
+				result.setPolicyVersion(getPolicy().getVersion());
 			}
 		}
 		if (LOG.isDebugEnabled()) {
@@ -876,18 +870,20 @@ public class RangerDefaultPolicyEvaluator extends RangerAbstractPolicyEvaluator
 							}
 						}
 					}
-					/* At least one access is allowed - this evaluator need not be checked for other accesses as the test below
+					/* At least one access is allowed or denied - this evaluator need not be checked for other accesses as the test below
 					 * implies that there is only one access group in the request
 					 */
 					if (oneRequest.isAccessTypeAny() || RangerAccessRequestUtil.getIsAnyAccessInContext(oneRequest.getContext())) {
-						if (allowResult != null) {
+						if (oneRequest.ignoreDescendantDeny() && allowResult != null) {
+							break;
+						} else if (!oneRequest.ignoreDescendantDeny() && denyResult != null) {
 							break;
 						}
 					}
 				}
 			}
 
-			RangerAccessResult compositeAccessResult = getCompositeAccessResult(request);
+			RangerAccessResult compositeAccessResult = getCompositeAccessResult(request, result);
 			if (compositeAccessResult != null) {
 				result.setAccessResultFrom(compositeAccessResult);
 			}
@@ -937,39 +933,54 @@ public class RangerDefaultPolicyEvaluator extends RangerAbstractPolicyEvaluator
 		return ret;
 	}
 
-	private RangerAccessResult getCompositeAccessResult(RangerAccessRequest request) {
-		RangerAccessResult 	ret 				= null;
-		Set<Set<String>> 	allAccessTypeGroups = RangerAccessRequestUtil.getAllRequestedAccessTypeGroups(request);
-		Set<String>      	allAccessTypes      = RangerAccessRequestUtil.getAllRequestedAccessTypes(request);
+	private RangerAccessResult getCompositeAccessResult(RangerAccessRequest request, RangerAccessResult result) {
+		RangerAccessResult ret                          = null;
+		Set<Set<String>>   allAccessTypeGroups          = RangerAccessRequestUtil.getAllRequestedAccessTypeGroups(request);
+		Set<String>        allAccessTypes               = RangerAccessRequestUtil.getAllRequestedAccessTypes(request);
+		Set<String>        ignoreIfNotDeniedAccessTypes = RangerAccessRequestUtil.getIgnoreIfNotDeniedAccessTypes(request);
 
 		if (CollectionUtils.isEmpty(allAccessTypeGroups)) {
 			ret = deriveAccessResultFromGroup(request, allAccessTypes);
+			if (ret == null && CollectionUtils.isNotEmpty(ignoreIfNotDeniedAccessTypes) && ignoreIfNotDeniedAccessTypes.containsAll(allAccessTypes)) {
+				// group does not allow/deny access and this group's all access-types are also in the ignore-if-not-denied access-type list
+				ret = new RangerAccessResult(result.getPolicyType(), result.getServiceName(), result.getServiceDef(), request);
+				ret.setAuditResultFrom(result);
+				ret.setIsAllowed(true);
+			}
 		} else {
-			boolean 			isAccessDetermined 	= true;
-			boolean				isAccessAllowed 	= false;
-			RangerAccessResult 	allowResult			= null;
+			boolean            isAccessDetermined = true;
+			boolean            isAccessAllowed    = false;
+			RangerAccessResult allowResult        = null;
 
 			for (Set<String> accessesInGroup : allAccessTypeGroups) {
 				RangerAccessResult groupResult = deriveAccessResultFromGroup(request, accessesInGroup);
 				if (groupResult != null) {
 					if (!groupResult.getIsAllowed()) {
 						// Deny
-						isAccessAllowed	= false;
-						ret				= groupResult;
+						isAccessAllowed = false;
+						ret             = groupResult;
 						break;
 					} else {
-						isAccessAllowed	= true;
+						isAccessAllowed = true;
 						if (allowResult == null) {
 							allowResult = groupResult;
 						}
 					}
 				} else {
 					// Some group is not completely authorized yet
-					isAccessDetermined = false;
+					if (!(CollectionUtils.isNotEmpty(ignoreIfNotDeniedAccessTypes) && ignoreIfNotDeniedAccessTypes.containsAll(accessesInGroup))) {
+						// group does not allow/deny access and this group's all access-types are also in the ignore-if-not-denied access-type list
+						isAccessDetermined = false;
+					}
 				}
 			}
+
 			if (isAccessDetermined && isAccessAllowed) {
 				ret = allowResult;
+			} else if (isAccessDetermined && ret == null) { // If none of the groups allowed/denied access and every group's all access-type results are to be ignored unless denied
+				ret = new RangerAccessResult(result.getPolicyType(), result.getServiceName(), result.getServiceDef(), request);
+				ret.setAuditResultFrom(result);
+				ret.setIsAllowed(true);
 			}
 		}
 		return ret;
