@@ -22,6 +22,7 @@ package org.apache.ranger.plugin.policyevaluator;
 
 import java.io.Serializable;
 import java.util.ArrayList;
+import java.util.Collection;
 import java.util.Comparator;
 import java.util.Date;
 import java.util.HashMap;
@@ -46,10 +47,12 @@ import org.apache.ranger.plugin.policyengine.RangerAccessResult;
 import org.apache.ranger.plugin.policyengine.RangerAccessResource;
 import org.apache.ranger.plugin.policyengine.RangerPolicyEngine;
 import org.apache.ranger.plugin.policyengine.RangerPolicyEngineOptions;
+import org.apache.ranger.plugin.policyengine.RangerResourceACLs;
 import org.apache.ranger.plugin.policyengine.RangerResourceACLs.DataMaskResult;
 import org.apache.ranger.plugin.policyengine.RangerResourceACLs.RowFilterResult;
 import org.apache.ranger.plugin.policyresourcematcher.RangerResourceEvaluator;
 import org.apache.ranger.plugin.policyresourcematcher.RangerPolicyResourceMatcher;
+import org.apache.ranger.plugin.policyresourcematcher.RangerPolicyResourceMatcher.MatchType;
 
 
 import static org.apache.ranger.plugin.policyevaluator.RangerPolicyItemEvaluator.POLICY_ITEM_TYPE_ALLOW;
@@ -91,6 +94,8 @@ public interface RangerPolicyEvaluator {
 
 	int getEvalOrder();
 
+	int getPolicyConditionsCount();
+
 	int getCustomConditionsCount();
 
 	int getValidityScheduleEvaluatorsCount();
@@ -99,6 +104,8 @@ public interface RangerPolicyEvaluator {
 
 	void evaluate(RangerAccessRequest request, RangerAccessResult result);
 
+	void getResourceACLs(RangerAccessRequest request, RangerResourceACLs acls, boolean isConditional, Set<String> targetAccessTypes, MatchType matchType, PolicyEngine policyEngine);
+
 	boolean isMatch(RangerAccessResource resource, Map<String, Object> evalContext);
 
 	boolean isCompleteMatch(RangerAccessResource resource, Map<String, Object> evalContext);
@@ -308,7 +315,7 @@ public interface RangerPolicyEvaluator {
 
 		public List<DataMaskResult> getDataMasks() { return dataMasks; }
 
-		void processPolicyItem(RangerPolicyItem policyItem, int policyItemType, boolean isConditional) {
+		void processPolicyItem(RangerPolicyItem policyItem, int policyItemType, boolean isConditional, Map<String, Collection<String>> impliedAccessGrants) {
 			final Integer result;
 			final boolean hasContextSensitiveSpecification = CollectionUtils.isNotEmpty(policyItem.getConditions());
 
@@ -335,15 +342,43 @@ public interface RangerPolicyEvaluator {
 			}
 
 			if (result != null) {
-				final List<RangerPolicyItemAccess> accesses;
+				List<RangerPolicyItemAccess> accesses = new ArrayList<>();
+				accesses.addAll(policyItem.getAccesses());
 
 				if (policyItem.getDelegateAdmin()) {
-					accesses = new ArrayList<>();
-
 					accesses.add(new RangerPolicyItemAccess(RangerPolicyEngine.ADMIN_ACCESS, policyItem.getDelegateAdmin()));
-					accesses.addAll(policyItem.getAccesses());
-				} else {
-					accesses = policyItem.getAccesses();
+				}
+
+				if(impliedAccessGrants != null && !impliedAccessGrants.isEmpty()) {
+					if (CollectionUtils.isNotEmpty(policyItem.getAccesses())) {
+
+						// Only one round of 'expansion' is done; multi-level impliedGrants (like shown below) are not handled for now
+						// multi-level impliedGrants: given admin=>write; write=>read: must imply admin=>read,write
+						for (Map.Entry<String, Collection<String>> e : impliedAccessGrants.entrySet()) {
+							String implyingAccessType = e.getKey();
+							Collection<String> impliedGrants = e.getValue();
+
+							RangerPolicyItemAccess access = RangerDefaultPolicyEvaluator.getAccess(policyItem, implyingAccessType);
+
+							if (access == null) {
+								continue;
+							}
+
+							for (String impliedGrant : impliedGrants) {
+								RangerPolicyItemAccess impliedAccess = RangerDefaultPolicyEvaluator.getAccess(policyItem, impliedGrant);
+
+								if (impliedAccess == null) {
+									impliedAccess = new RangerPolicyItemAccess(impliedGrant, access.getIsAllowed());
+
+									accesses.add(impliedAccess);
+								} else {
+									if (!impliedAccess.getIsAllowed()) {
+										impliedAccess.setIsAllowed(access.getIsAllowed());
+									}
+								}
+							}
+						}
+					}
 				}
 
 				final List<String> groups         = policyItem.getGroups();
