@@ -19,14 +19,17 @@
 
 package org.apache.ranger.plugin.service;
 
+import java.io.IOException;
 import java.util.*;
 import org.apache.commons.collections.CollectionUtils;
 import org.apache.commons.collections.MapUtils;
 import org.apache.commons.lang.StringUtils;
+import org.apache.hadoop.security.UserGroupInformation;
 import org.apache.ranger.admin.client.RangerAdminClient;
 import org.apache.ranger.admin.client.RangerAdminRESTClient;
 import org.apache.ranger.audit.provider.AuditHandler;
 import org.apache.ranger.audit.provider.AuditProviderFactory;
+import org.apache.ranger.audit.provider.MiscUtil;
 import org.apache.ranger.audit.provider.StandAloneAuditProviderFactory;
 import org.apache.ranger.authorization.hadoop.config.RangerAuditConfig;
 import org.apache.ranger.authorization.hadoop.config.RangerPluginConfig;
@@ -73,6 +76,7 @@ public class RangerBasePlugin {
 	private final List<RangerChainedPlugin>   chainedPlugins;
 	private final boolean                     dedupStrings;
 	private       boolean                     isUserStoreEnricherAddedImplcitly = false;
+	private       Map<String, String>         serviceConfigs;
 
 
 	public RangerBasePlugin(String serviceType, String appId) {
@@ -110,6 +114,58 @@ public class RangerBasePlugin {
 		setIsFallbackSupported(pluginConfig.getBoolean(pluginConfig.getPropertyPrefix() + ".is.fallback.supported", false));
 		setServiceAdmins(serviceAdmins);
 
+		String  ugiPrefix = pluginConfig.getPropertyPrefix() + ".ugi";
+		boolean initUgi   = pluginConfig.getBoolean(ugiPrefix + ".initialize", false);
+
+		if (initUgi) {
+			String ugiLoginType = pluginConfig.get(ugiPrefix + ".login.type");
+
+			if (StringUtils.equalsIgnoreCase(ugiLoginType, "keytab")) {
+				String principal = pluginConfig.get(ugiPrefix + ".keytab.principal");
+				String keytab    = pluginConfig.get(ugiPrefix + ".keytab.file");
+
+				if (StringUtils.isNotBlank(principal) && StringUtils.isNotBlank(keytab)) {
+					LOG.info("UGI login: principal={}, keytab={}", principal, keytab);
+
+					try {
+						UserGroupInformation.loginUserFromKeytab(principal, keytab);
+					} catch (IOException excp) {
+						LOG.error("UGI login: failed", excp);
+
+						throw new RuntimeException(excp);
+					}
+				} else {
+					String msg = String.format("UGI login: invalid configuration: %s=%s, %s=%s", ugiPrefix + ".keytab.principal", principal, ugiPrefix + ".keytab.file", keytab);
+
+					LOG.error(msg);
+
+					throw new RuntimeException(msg);
+				}
+			} else if (StringUtils.equalsIgnoreCase(ugiLoginType, "jaas")) {
+				String jaasAppConfig = pluginConfig.get(ugiPrefix + ".jaas.appconfig");
+
+				if (StringUtils.isNotBlank(jaasAppConfig)) {
+					LOG.info("UGI login: jaasAppConfig={}", jaasAppConfig);
+
+					try {
+						MiscUtil.setUGIFromJAASConfig(jaasAppConfig);
+					} catch (Exception excp) {
+						LOG.error("UGI login: jaasAppConfig={} failed", jaasAppConfig, excp);
+
+						throw new RuntimeException(excp);
+					}
+				} else {
+					String msg = String.format("UGI login: invalid configuration: %s=%s", ugiPrefix + ".jaas.appconfig", jaasAppConfig);
+
+					LOG.error(msg);
+
+					throw new RuntimeException(msg);
+				}
+			} else {
+				LOG.warn("UGI login: invalid configuration {}={}", ugiPrefix + ".login.type", ugiLoginType);
+			}
+		}
+
 		RangerRequestScriptEvaluator.init(pluginConfig);
 
 		this.dedupStrings   = pluginConfig.getBoolean(pluginConfig.getPropertyPrefix() + ".dedup.strings", true);
@@ -291,7 +347,7 @@ public class RangerBasePlugin {
 		if (LOG.isDebugEnabled()) {
 			LOG.debug("==> setPolicies(" + policies + ")");
 		}
-
+		this.serviceConfigs = (policies != null && policies.getServiceConfig() != null) ? policies.getServiceConfig() : new HashMap<>();
 		if (pluginConfig.isEnableImplicitUserStoreEnricher() && policies != null && !ServiceDefUtil.isUserStoreEnricherPresent(policies)) {
 			String retrieverClassName = pluginConfig.get(RangerUserStoreEnricher.USERSTORE_RETRIEVER_CLASSNAME_OPTION, RangerAdminUserStoreRetriever.class.getCanonicalName());
 			String retrieverPollIntMs = pluginConfig.get(RangerUserStoreEnricher.USERSTORE_REFRESHER_POLLINGINTERVAL_OPTION, Integer.toString(60 * 1000));
@@ -509,7 +565,7 @@ public class RangerBasePlugin {
 			ret = policyEngine.evaluatePolicies(request, RangerPolicy.POLICY_TYPE_ACCESS, null);
 		}
 
-		if (ret != null && !RangerAccessRequestUtil.getIsSkipChainedPlugins(request.getContext())) {
+		if (ret != null) {
 			for (RangerChainedPlugin chainedPlugin : chainedPlugins) {
 				if (LOG.isDebugEnabled()) {
 					LOG.debug("BasePlugin.isAccessAllowed result=[" + ret + "]");
@@ -1172,6 +1228,10 @@ public class RangerBasePlugin {
 		return baseACLs;
 	}
 
+	public Map<String, String> getServiceConfigs() {
+		return serviceConfigs;
+	}
+
 	protected RangerPolicyEngine getPolicyEngine() {
 		return policyEngine;
 	}
