@@ -23,19 +23,21 @@ import java.util.List;
 import java.util.Map;
 
 import org.apache.commons.collections.ListUtils;
-import org.apache.commons.collections.MapUtils;
 import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
 
 public class RangerDefaultService extends RangerBaseService {
 	private static final Logger LOG = LoggerFactory.getLogger(RangerDefaultService.class);
-		
+
+	public static final String ERROR_MSG_VALIDATE_CONFIG_NOT_IMPLEMENTED = "Configuration validation is not implemented";
+
 	@Override
 	public  Map<String, Object> validateConfig() throws Exception {
-		if(LOG.isDebugEnabled()) {
-			LOG.debug("RangerDefaultService.validateConfig Service: (" + serviceName + " ), returning empty map");
+		if (LOG.isDebugEnabled()) {
+			LOG.debug("RangerDefaultService.validateConfig Service: (" + serviceName + " ), " + ERROR_MSG_VALIDATE_CONFIG_NOT_IMPLEMENTED);
 		}
-		return MapUtils.EMPTY_MAP;
+
+		throw new Exception(ERROR_MSG_VALIDATE_CONFIG_NOT_IMPLEMENTED);
 	}
 	
 	@Override
