@@ -21,6 +21,10 @@ package org.apache.ranger.plugin.util;
 
 public class RangerCommonConstants {
 
+	private RangerCommonConstants() {
+
+	}
+
 	public static final String PROP_COOKIE_NAME                             = "ranger.admin.cookie.name";
 	public static final String DEFAULT_COOKIE_NAME                          = "RANGERADMINSESSIONID";
 
@@ -36,7 +40,7 @@ public class RangerCommonConstants {
 	public static final String RANGER_ADMIN_SUFFIX_IN_PLACE_TAG_UPDATES     = ".supports.in.place.tag.updates";
 	public static final String PLUGIN_CONFIG_SUFFIX_IN_PLACE_TAG_UPDATES    = ".supports.in.place.tag.updates";
 
-	public static final String  RANGER_ADMIN_SUPPORTS_TAGS_DEDUP            = ".supports.tags.dedup";
+	public static final String RANGER_SUPPORTS_TAGS_DEDUP                   = ".supports.tags.dedup";
 
 	public static final boolean RANGER_ADMIN_SUFFIX_POLICY_DELTA_DEFAULT             = false;
 	public static final boolean PLUGIN_CONFIG_SUFFIX_POLICY_DELTA_DEFAULT            = false;
@@ -50,7 +54,7 @@ public class RangerCommonConstants {
 	public static final boolean RANGER_ADMIN_SUFFIX_IN_PLACE_TAG_UPDATES_DEFAULT     = false;
 	public static final boolean PLUGIN_CONFIG_SUFFIX_IN_PLACE_TAG_UPDATES_DEFAULT    = false;
 
-	public static final boolean RANGER_ADMIN_SUPPORTS_TAGS_DEDUP_DEFAULT             = true;
+	public static final boolean RANGER_SUPPORTS_TAGS_DEDUP_DEFAULT                   = true;
 
 	public static final boolean POLICY_REST_CLIENT_SESSION_COOKIE_ENABLED            = true;
 
@@ -82,6 +86,9 @@ public class RangerCommonConstants {
 	public static final String SCRIPT_FIELD_FORWARDED_ADDRESSES     = "forwardedAddresses";
 	public static final String SCRIPT_FIELD__MATCH_TYPE             = "_matchType";
 	public static final String SCRIPT_FIELD__NAME                   = "_name";
+	public static final String SCRIPT_FIELD__SYNC_SOURCE            = "_syncSource";
+	public static final String SCRIPT_FIELD__IS_INTERNAL            = "_isInternal";
+	public static final String SCRIPT_FIELD__EMAIL_ADDRESS          = "_emailAddress";
 	public static final String SCRIPT_FIELD__OWNER_USER             = "_ownerUser";
 	public static final String SCRIPT_FIELD_REMOTE_IP_ADDRESS       = "remoteIPAddress";
 	public static final String SCRIPT_FIELD_REQUEST                 = "request";
@@ -147,6 +154,9 @@ public class RangerCommonConstants {
 	public static final String SCRIPT_MACRO_IS_IN_ANY_ROLE        = "IS_IN_ANY_ROLE";
 	public static final String SCRIPT_MACRO_IS_NOT_IN_ANY_GROUP   = "IS_NOT_IN_ANY_GROUP";
 	public static final String SCRIPT_MACRO_IS_NOT_IN_ANY_ROLE    = "IS_NOT_IN_ANY_ROLE";
+	public static final String SCRIPT_MACRO_IS_ACCESS_TIME_AFTER   = "IS_ACCESS_TIME_AFTER";
+	public static final String SCRIPT_MACRO_IS_ACCESS_TIME_BEFORE  = "IS_ACCESS_TIME_BEFORE";
+	public static final String SCRIPT_MACRO_IS_ACCESS_TIME_BETWEEN = "IS_ACCESS_TIME_BETWEEN";
 
 	public static final String SCRIPT_POLYFILL_INCLUDES = "if (!Array.prototype.includes) {\n" +
 			"    Object.defineProperty(\n" +
@@ -169,13 +179,13 @@ public class RangerCommonConstants {
 			"      Array.prototype, 'intersects', {\n" +
 			"          value: function (x) {\n" +
 			"           if (x == null) {return false;}\n" +
-			"                        var o = Object(this);\n" +
-			"                        var len = o.length >>> 0;\n" +
-			"            if (len === 0) { return false; }\n" +
-			"            var result = o.filter(function(n) { return x.indexOf(n) > -1;})\n" +
-			"            return result.length != 0;\n" +
+			"           var o = Object(this);\n" +
+			"           var len = o.length >>> 0;\n" +
+			"           if (len === 0) { return false; }\n" +
+			"           var result = o.filter(function(n) { return x.indexOf(n) > -1;})\n" +
+			"           return result.length != 0;\n" +
 			"        }\n" +
 			"      }\n" +
-			"    )\n" +
+			"    );\n" +
 			"}; ";
 }
