@@ -46,9 +46,11 @@ import javax.net.ssl.TrustManagerFactory;
 import javax.ws.rs.core.Cookie;
 
 import com.fasterxml.jackson.jaxrs.json.JacksonJsonProvider;
+import com.sun.jersey.api.client.filter.ClientFilter;
 import org.apache.commons.lang.StringUtils;
 import org.apache.commons.lang.Validate;
 import org.apache.hadoop.conf.Configuration;
+import org.apache.ranger.authorization.hadoop.config.RangerPluginConfig;
 import org.apache.ranger.authorization.hadoop.utils.RangerCredentialProvider;
 import org.apache.ranger.authorization.utils.JsonUtils;
 import org.apache.ranger.authorization.utils.StringUtil;
@@ -110,7 +112,8 @@ public class RangerRESTClient {
 	private final List<String> configuredURLs;
 
 	private volatile Client client;
-
+	private volatile Client cookieAuthClient;
+	private ClientFilter    basicAuthFilter = null;
 
 	public RangerRESTClient(String url, String sslConfigFileName, Configuration config) {
 		mUrl               = url;
@@ -165,6 +168,8 @@ public class RangerRESTClient {
 	public void setBasicAuthInfo(String username, String password) {
 		mUsername = username;
 		mPassword = password;
+
+		setBasicAuthFilter(username, password);
 	}
 
 	public WebResource getResource(String relativeUrl) {
@@ -196,6 +201,28 @@ public class RangerRESTClient {
 		return result;
 	}
 
+	private Client getCookieAuthClient() {
+		Client ret = cookieAuthClient;
+
+		if (ret == null) {
+			synchronized (this) {
+				ret = cookieAuthClient;
+
+				if (ret == null) {
+					cookieAuthClient = buildClient();
+
+					if (basicAuthFilter != null) {
+						cookieAuthClient.removeFilter(basicAuthFilter);
+					}
+
+					ret = cookieAuthClient;
+				}
+			}
+		}
+
+		return ret;
+	}
+
 	private Client buildClient() {
 		Client client = null;
 
@@ -226,8 +253,8 @@ public class RangerRESTClient {
 			client = Client.create(config);
 		}
 
-		if(StringUtils.isNotEmpty(mUsername) && StringUtils.isNotEmpty(mPassword)) {
-			client.addFilter(new HTTPBasicAuthFilter(mUsername, mPassword));
+		if (basicAuthFilter != null && !client.isFilterPresent(basicAuthFilter)) {
+			client.addFilter(basicAuthFilter);
 		}
 
 		// Set Connection Timeout and ReadTime for the PolicyRefresh
@@ -237,6 +264,14 @@ public class RangerRESTClient {
 		return client;
 	}
 
+	private void setBasicAuthFilter(String username, String password) {
+		if (StringUtils.isNotEmpty(username) && StringUtils.isNotEmpty(password)) {
+			basicAuthFilter = new HTTPBasicAuthFilter(username, password);
+		} else {
+			basicAuthFilter = null;
+		}
+	}
+
 	public void resetClient(){
 		client = null;
 	}
@@ -271,6 +306,21 @@ public class RangerRESTClient {
 			}
 
 		}
+
+		final String pluginPropertyPrefix;
+
+		if (config instanceof RangerPluginConfig) {
+			pluginPropertyPrefix = ((RangerPluginConfig) config).getPropertyPrefix();
+		} else {
+			pluginPropertyPrefix = "ranger.plugin";
+		}
+
+		String username = config.get(pluginPropertyPrefix + ".policy.rest.client.username");
+		String password = config.get(pluginPropertyPrefix + ".policy.rest.client.password");
+
+		if (StringUtils.isNotBlank(username) && StringUtils.isNotBlank(password)) {
+			setBasicAuthFilter(username, password);
+		}
 	}
 
 	private boolean isSslEnabled(String url) {
@@ -455,15 +505,13 @@ public class RangerRESTClient {
 	public ClientResponse get(String relativeUrl, Map<String, String> params) throws Exception {
 		ClientResponse finalResponse = null;
 		int startIndex = this.lastKnownActiveUrlIndex;
-		int currentIndex = 0;
 		int retryAttempt = 0;
 
 		for (int index = 0; index < configuredURLs.size(); index++) {
-			try {
-				currentIndex = (startIndex + index) % configuredURLs.size();
+			int currentIndex = (startIndex + index) % configuredURLs.size();
 
-				WebResource webResource = getClient().resource(configuredURLs.get(currentIndex) + relativeUrl);
-				webResource = setQueryParams(webResource, params);
+			try {
+				WebResource.Builder webResource = createWebResource(currentIndex, relativeUrl, params);
 
 				finalResponse = webResource.accept(RangerRESTUtils.REST_EXPECTED_MIME_TYPE).type(RangerRESTUtils.REST_MIME_TYPE_JSON).get(ClientResponse.class);
 
@@ -485,16 +533,14 @@ public class RangerRESTClient {
 	public ClientResponse get(String relativeUrl, Map<String, String> params, Cookie sessionId) throws Exception{
 		ClientResponse finalResponse = null;
 		int startIndex = this.lastKnownActiveUrlIndex;
-		int currentIndex = 0;
 		int retryAttempt = 0;
 
 		for (int index = 0; index < configuredURLs.size(); index++) {
+			int currentIndex = (startIndex + index) % configuredURLs.size();
+
 			try {
-				currentIndex = (startIndex + index) % configuredURLs.size();
+				WebResource.Builder br = createWebResource(currentIndex, relativeUrl, params, sessionId);
 
-				WebResource webResource = createWebResourceForCookieAuth(currentIndex, relativeUrl);
-				webResource = setQueryParams(webResource, params);
-				WebResource.Builder br = webResource.getRequestBuilder().cookie(sessionId);
 				finalResponse = br.accept(RangerRESTUtils.REST_EXPECTED_MIME_TYPE).type(RangerRESTUtils.REST_MIME_TYPE_JSON).get(ClientResponse.class);
 
 				if (finalResponse != null) {
@@ -515,15 +561,14 @@ public class RangerRESTClient {
 	public ClientResponse post(String relativeUrl, Map<String, String> params, Object obj) throws Exception {
 		ClientResponse finalResponse = null;
 		int startIndex = this.lastKnownActiveUrlIndex;
-		int currentIndex = 0;
 		int retryAttempt = 0;
 
 		for (int index = 0; index < configuredURLs.size(); index++) {
+			int currentIndex = (startIndex + index) % configuredURLs.size();
+
 			try {
-				currentIndex = (startIndex + index) % configuredURLs.size();
+				WebResource.Builder webResource = createWebResource(currentIndex, relativeUrl, params);
 
-				WebResource webResource = getClient().resource(configuredURLs.get(currentIndex) + relativeUrl);
-				webResource = setQueryParams(webResource, params);
 				finalResponse = webResource.accept(RangerRESTUtils.REST_EXPECTED_MIME_TYPE).type(RangerRESTUtils.REST_MIME_TYPE_JSON).post(ClientResponse.class, toJson(obj));
 				if (finalResponse != null) {
 					setLastKnownActiveUrlIndex(currentIndex);
@@ -543,18 +588,17 @@ public class RangerRESTClient {
 	public ClientResponse post(String relativeURL, Map<String, String> params, Object obj, Cookie sessionId) throws Exception {
 		ClientResponse response = null;
 		int startIndex = this.lastKnownActiveUrlIndex;
-		int currentIndex = 0;
 		int retryAttempt = 0;
 
 		for (int index = 0; index < configuredURLs.size(); index++) {
+			int currentIndex = (startIndex + index) % configuredURLs.size();
+
 			try {
-				currentIndex = (startIndex + index) % configuredURLs.size();
+				WebResource.Builder br = createWebResource(currentIndex, relativeURL, params, sessionId);
 
-				WebResource webResource = createWebResourceForCookieAuth(currentIndex, relativeURL);
-				webResource = setQueryParams(webResource, params);
-				WebResource.Builder br = webResource.getRequestBuilder().cookie(sessionId);
 				response = br.accept(RangerRESTUtils.REST_EXPECTED_MIME_TYPE).type(RangerRESTUtils.REST_MIME_TYPE_JSON)
 						.post(ClientResponse.class, toJson(obj));
+
 				if (response != null) {
 					setLastKnownActiveUrlIndex(currentIndex);
 					break;
@@ -573,15 +617,13 @@ public class RangerRESTClient {
 	public ClientResponse delete(String relativeUrl, Map<String, String> params) throws Exception {
 		ClientResponse finalResponse = null;
 		int startIndex = this.lastKnownActiveUrlIndex;
-		int currentIndex = 0;
 		int retryAttempt = 0;
 
 		for (int index = 0; index < configuredURLs.size(); index++) {
-			try {
-				currentIndex = (startIndex + index) % configuredURLs.size();
+			int currentIndex = (startIndex + index) % configuredURLs.size();
 
-				WebResource webResource = getClient().resource(configuredURLs.get(currentIndex) + relativeUrl);
-				webResource = setQueryParams(webResource, params);
+			try {
+				WebResource.Builder webResource = createWebResource(currentIndex, relativeUrl, params);
 
 				finalResponse = webResource.accept(RangerRESTUtils.REST_EXPECTED_MIME_TYPE).type(RangerRESTUtils.REST_MIME_TYPE_JSON).delete(ClientResponse.class);
 				if (finalResponse != null) {
@@ -602,17 +644,16 @@ public class RangerRESTClient {
 	public ClientResponse delete(String relativeURL, Map<String, String> params, Cookie sessionId) throws Exception {
 		ClientResponse response = null;
 		int startIndex = this.lastKnownActiveUrlIndex;
-		int currentIndex = 0;
 		int retryAttempt = 0;
 
 		for (int index = 0; index < configuredURLs.size(); index++) {
+			int currentIndex = (startIndex + index) % configuredURLs.size();
+
 			try {
-				currentIndex = (startIndex + index) % configuredURLs.size();
+				WebResource.Builder br = createWebResource(currentIndex, relativeURL, params, sessionId);
 
-				WebResource webResource = createWebResourceForCookieAuth(currentIndex, relativeURL);
-				webResource = setQueryParams(webResource, params);
-				WebResource.Builder br = webResource.getRequestBuilder().cookie(sessionId);
 				response = br.delete(ClientResponse.class);
+
 				if (response != null) {
 					setLastKnownActiveUrlIndex(currentIndex);
 					break;
@@ -631,15 +672,14 @@ public class RangerRESTClient {
 	public ClientResponse put(String relativeUrl, Map<String, String> params, Object obj) throws Exception {
 		ClientResponse finalResponse = null;
 		int startIndex = this.lastKnownActiveUrlIndex;
-		int currentIndex = 0;
 		int retryAttempt = 0;
 
 		for (int index = 0; index < configuredURLs.size(); index++) {
+			int currentIndex = (startIndex + index) % configuredURLs.size();
+
 			try {
-				currentIndex = (startIndex + index) % configuredURLs.size();
+				WebResource.Builder webResource = createWebResource(currentIndex, relativeUrl, params);
 
-				WebResource webResource = getClient().resource(configuredURLs.get(currentIndex) + relativeUrl);
-				webResource = setQueryParams(webResource, params);
 				finalResponse = webResource.accept(RangerRESTUtils.REST_EXPECTED_MIME_TYPE).type(RangerRESTUtils.REST_MIME_TYPE_JSON).put(ClientResponse.class, toJson(obj));
 				if (finalResponse != null) {
 					setLastKnownActiveUrlIndex(currentIndex);
@@ -659,17 +699,17 @@ public class RangerRESTClient {
 	public ClientResponse put(String relativeURL, Object request, Cookie sessionId) throws Exception {
 		ClientResponse response = null;
 		int startIndex = this.lastKnownActiveUrlIndex;
-		int currentIndex = 0;
 		int retryAttempt = 0;
 
 		for (int index = 0; index < configuredURLs.size(); index++) {
+			int currentIndex = (startIndex + index) % configuredURLs.size();
+
 			try {
-				currentIndex = (startIndex + index) % configuredURLs.size();
+				WebResource.Builder br = createWebResource(currentIndex, relativeURL, null, sessionId);
 
-				WebResource webResource = createWebResourceForCookieAuth(currentIndex, relativeURL);
-				WebResource.Builder br = webResource.getRequestBuilder().cookie(sessionId);
 				response = br.accept(RangerRESTUtils.REST_EXPECTED_MIME_TYPE).type(RangerRESTUtils.REST_MIME_TYPE_JSON)
 						.put(ClientResponse.class, toJson(request));
+
 				if (response != null) {
 					setLastKnownActiveUrlIndex(currentIndex);
 					break;
@@ -700,11 +740,24 @@ public class RangerRESTClient {
 		this.lastKnownActiveUrlIndex = lastKnownActiveUrlIndex;
 	}
 
-	protected WebResource createWebResourceForCookieAuth(int currentIndex, String relativeURL) {
-		Client cookieClient = getClient();
-		cookieClient.removeAllFilters();
-		WebResource ret = cookieClient.resource(configuredURLs.get(currentIndex) + relativeURL);
-		return ret;
+	protected WebResource.Builder createWebResource(int currentIndex, String relativeURL, Map<String, String> params) {
+		WebResource webResource = getClient().resource(configuredURLs.get(currentIndex) + relativeURL);
+
+		webResource = setQueryParams(webResource, params);
+
+		return webResource.getRequestBuilder();
+	}
+
+	protected WebResource.Builder createWebResource(int currentIndex, String relativeURL, Map<String, String> params, Cookie sessionId) {
+		if (sessionId == null) {
+			return createWebResource(currentIndex, relativeURL, params);
+		} else {
+			WebResource webResource = getCookieAuthClient().resource(configuredURLs.get(currentIndex) + relativeURL);
+
+			webResource = setQueryParams(webResource, params);
+
+			return webResource.getRequestBuilder().cookie(sessionId);
+		}
 	}
 
 	protected boolean shouldRetry(String currentUrl, int index, int retryAttemptCount, Exception ex) throws Exception {
