@@ -67,23 +67,33 @@ RUN yum install -y wget
 RUN yum install -y git
 RUN yum install -y gcc
 RUN yum install -y bzip2 fontconfig
+RUN yum install -y diffutils
+RUN yum install -y python3
+
+RUN ln -s /usr/bin/python3 /usr/bin/python
+
+RUN yum install -y java-1.8.0-openjdk java-1.8.0-openjdk-devel
+#ENV JAVA_HOME /etc/alternatives/jre
+ENV JAVA_HOME /usr/lib/jvm/java-1.8.0-openjdk/
+ENV PATH $JAVA_HOME/bin:$PATH
 
 #Download and install JDK8 from AWS s3's docker-assets 
-RUN wget https://s3.eu-central-1.amazonaws.com/docker-assets/dist/jdk-8u101-linux-x64.rpm
-RUN rpm -i jdk-8u101-linux-x64.rpm
-
-ENV JAVA_HOME /usr/java/latest
-ENV  PATH $JAVA_HOME/bin:$PATH
+#RUN wget https://s3.eu-central-1.amazonaws.com/docker-assets/dist/jdk-8u101-linux-x64.rpm
+#RUN rpm -i jdk-8u101-linux-x64.rpm
+#ENV JAVA_HOME /usr/java/latest
+#ENV  PATH $JAVA_HOME/bin:$PATH
 
 
-ADD https://www.apache.org/dist/maven/maven-3/3.5.4/binaries/apache-maven-3.5.4-bin.tar.gz.sha512 /tools
-ADD http://www-us.apache.org/dist/maven/maven-3/3.5.4/binaries/apache-maven-3.5.4-bin.tar.gz /tools
-RUN sha512sum  apache-maven-3.5.4-bin.tar.gz | cut -f 1 -d " " > tmp.sha1
+ADD https://www.apache.org/dist/maven/maven-3/3.6.3/binaries/apache-maven-3.6.3-bin.tar.gz.sha512 /tools
+ADD http://www-us.apache.org/dist/maven/maven-3/3.6.3/binaries/apache-maven-3.6.3-bin.tar.gz /tools
+RUN sha512sum  apache-maven-3.6.3-bin.tar.gz | cut -f 1 -d " " > tmp.sha1
 
-RUN diff -w tmp.sha1 apache-maven-3.5.4-bin.tar.gz.sha512
+RUN cat apache-maven-3.6.3-bin.tar.gz.sha512 | cut -f 1 -d " " > tmp.sha1.download
 
-RUN tar xfz apache-maven-3.5.4-bin.tar.gz
-RUN ln -sf /tools/apache-maven-3.5.4 /tools/maven
+RUN diff -w tmp.sha1 tmp.sha1.download
+
+RUN tar xfz apache-maven-3.6.3-bin.tar.gz
+RUN ln -sf /tools/apache-maven-3.6.3 /tools/maven
 
 ENV  PATH /tools/maven/bin:$PATH
 ENV MAVEN_OPTS "-Xmx2048m -XX:MaxPermSize=512m"
