@@ -26,9 +26,13 @@ fi
 
 if [ "${SETUP_RANGER}" == "true" ]
 then
-  cd ${RANGER_HOME}/admin && ./setup.sh
-
-  touch ${RANGER_HOME}/.setupDone
+  cd "${RANGER_HOME}"/admin || exit
+  if ./setup.sh;
+  then
+    touch "${RANGER_HOME}"/.setupDone
+  else
+    echo "Ranger Admin Setup Script didn't complete proper execution."
+  fi
 fi
 
 cd ${RANGER_HOME}/admin && ./ews/ranger-admin-services.sh start
@@ -43,4 +47,9 @@ fi
 RANGER_ADMIN_PID=`ps -ef  | grep -v grep | grep -i "org.apache.ranger.server.tomcat.EmbeddedServer" | awk '{print $2}'`
 
 # prevent the container from exiting
-tail --pid=$RANGER_ADMIN_PID -f /dev/null
+if [ -z "$RANGER_ADMIN_PID" ]
+then
+  echo "Ranger Admin process probably exited, no process id found!"
+else
+  tail --pid=$RANGER_ADMIN_PID -f /dev/null
+fi
