@@ -17,44 +17,36 @@
  * under the License.
  */
 
- package org.apache.ranger.server.tomcat;
+package org.apache.ranger.server.tomcat;
 
 import java.io.PrintWriter;
 import java.net.Socket;
 
 public class StopEmbeddedServer extends EmbeddedServer {
 
-	private static final String SHUTDOWN_HOSTNAME = "localhost";
-	
-	public static void main(String[] args) {
-		new StopEmbeddedServer(args).stop();
-	}
+    private static final String SHUTDOWN_HOSTNAME = "localhost";
+
+    public static void main(String[] args) {
+        new StopEmbeddedServer(args).stop();
+    }
+
+    public StopEmbeddedServer(String[] args) {
+        super(args);
+    }
+
+    public void stop() {
+
+        int    shutdownPort    = EmbeddedServerUtil.getIntConfig("ranger.service.shutdown.port", DEFAULT_SHUTDOWN_PORT);
+        String shutdownCommand = EmbeddedServerUtil.getConfig("ranger.service.shutdown.command", DEFAULT_SHUTDOWN_COMMAND);
+
+        try (Socket sock = new Socket(SHUTDOWN_HOSTNAME, shutdownPort);
+			 PrintWriter out = new PrintWriter(sock.getOutputStream(), true)) {
+            out.println(shutdownCommand);
+            out.flush();
+        } catch (Throwable t) {
+            System.err.println("Server could not be shutdown due to exception:" + t);
+            System.exit(1);
+        }
+    }
 
-	public StopEmbeddedServer(String[] args) {
-		super(args);
-	}
-	
-	public void stop() {
-		
-		try {
-			
-			int shutdownPort = getIntConfig("ranger.service.shutdown.port", DEFAULT_SHUTDOWN_PORT );
-			String shutdownCommand = getConfig("ranger.service.shutdown.command", DEFAULT_SHUTDOWN_COMMAND );
-			
-			Socket sock = new Socket(SHUTDOWN_HOSTNAME,shutdownPort);
-			
-			PrintWriter out = new PrintWriter(sock.getOutputStream(), true);
-			
-			out.println(shutdownCommand);
-			
-			out.flush();
-			
-			out.close();
-		}
-		catch(Throwable t) {
-			System.err.println("Server could not be shutdown due to exception:" +  t);
-			System.exit(1);
-		}
-	}
-	
 }
