@@ -21,15 +21,16 @@ package org.apache.ranger.authorization.hbase;
 import java.util.ArrayList;
 import java.util.List;
 
-import org.apache.commons.logging.Log;
-import org.apache.commons.logging.LogFactory;
 import org.apache.ranger.audit.model.AuthzAuditEvent;
 import org.apache.ranger.plugin.audit.RangerDefaultAuditHandler;
+import org.apache.ranger.plugin.policyengine.RangerAccessRequest;
 import org.apache.ranger.plugin.policyengine.RangerAccessResult;
+import org.slf4j.Logger;
+import org.slf4j.LoggerFactory;
 
 public class HbaseAuditHandlerImpl extends RangerDefaultAuditHandler implements HbaseAuditHandler {
 
-	private static final Log LOG = LogFactory.getLog(HbaseAuditHandlerImpl.class);
+	private static final Logger LOG = LoggerFactory.getLogger(HbaseAuditHandlerImpl.class);
 	static final List<AuthzAuditEvent> _EmptyList = new ArrayList<AuthzAuditEvent>();
 	final List<AuthzAuditEvent> _allEvents = new ArrayList<AuthzAuditEvent>();
 	// we replace its contents anytime new audit events are generated.
@@ -42,6 +43,7 @@ public class HbaseAuditHandlerImpl extends RangerDefaultAuditHandler implements
 			LOG.debug("==> HbaseAuditHandlerImpl.getAuthzEvents(" + result + ")");
 		}
 
+		resetResourceForAudit(result.getAccessRequest());
 		AuthzAuditEvent event = super.getAuthzEvents(result);
 		// first accumulate last set of events and then capture these as the most recent ones
 		if (_mostRecentEvent != null) {
@@ -147,4 +149,17 @@ public class HbaseAuditHandlerImpl extends RangerDefaultAuditHandler implements
 			LOG.debug("<== HbaseAuditHandlerImpl.applySuperUserOverride(...)");
 		}
 	}
+
+	private void resetResourceForAudit(RangerAccessRequest request) {
+		if (LOG.isDebugEnabled()) {
+			LOG.debug("==> HbaseAuditHandlerImpl.resetResourceForAudit(" + request + ")");
+		}
+		if (request != null && request.getResource() instanceof RangerHBaseResource) {
+			RangerHBaseResource hbaseResource = (RangerHBaseResource) request.getResource();
+			hbaseResource.resetValue(RangerHBaseResource.KEY_TABLE);
+		}
+		if(LOG.isDebugEnabled()) {
+			LOG.debug("<== HbaseAuditHandlerImpl.resetResourceForAudit(" + request + ")");
+		}
+	}
 }
