@@ -23,7 +23,7 @@ import java.io.UnsupportedEncodingException;
 import java.lang.reflect.Type;
 import java.net.InetAddress;
 import java.net.UnknownHostException;
-import java.security.PrivilegedAction;
+import java.security.PrivilegedExceptionAction;
 import java.util.Date;
 import java.util.HashMap;
 import java.util.List;
@@ -305,20 +305,17 @@ public class RangerAdminJersey2RESTClient extends AbstractRangerAdminClient {
 				LOG.debug("Checking UserStore updated as user: {}", user);
 			}
 
-			PrivilegedAction<Response> action = () -> {
-				Response resp        = null;
-				String   relativeURL = RangerRESTUtils.REST_URL_SERVICE_SERCURE_GET_USERSTORE + _serviceNameUrlParam;
-
+			response = MiscUtil.executePrivilegedAction((PrivilegedExceptionAction<Response>) () -> {
 				try {
-					resp = get(queryParams, relativeURL);
+					String relativeURL = RangerRESTUtils.REST_URL_SERVICE_SERCURE_GET_USERSTORE + _serviceNameUrlParam;
+
+					return get(queryParams, relativeURL);
 				} catch (Exception e) {
 					LOG.error("Failed to get response", e);
 				}
 
-				return resp;
-			};
-
-			response = user.doAs(action);
+				return null;
+			});
 		} else {
 			if (LOG.isDebugEnabled()) {
 				LOG.debug("Checking UserStore updated as user: {}", user);
@@ -539,9 +536,7 @@ public class RangerAdminJersey2RESTClient extends AbstractRangerAdminClient {
 
 		final ServicePolicies ret;
 
-		final UserGroupInformation user         = MiscUtil.getUGILoginUser();
-		final boolean              isSecureMode = isKerberosEnabled(user);
-		final Response             response     = getRangerAdminPolicyDownloadResponse(lastKnownVersion, lastActivationTimeInMillis, user, isSecureMode);
+		final Response response = getRangerAdminPolicyDownloadResponse(lastKnownVersion, lastActivationTimeInMillis);
 
 		int httpResponseCode = response == null ? -1 : response.getStatus();
 		String body = null;
@@ -587,7 +582,7 @@ public class RangerAdminJersey2RESTClient extends AbstractRangerAdminClient {
 				ret = null;
 				policyDownloadSessionId = null;
 				body = response.readEntity(String.class);
-				LOG.warn(String.format("Unexpected: Received status[%d] with body[%s] form url[%s]", httpResponseCode, body, getRelativeURL(isSecureMode)));
+				LOG.warn(String.format("Unexpected: Received status[%d] with body[%s] form url[%s]", httpResponseCode, body, getRelativeURL(isSecureMode())));
 				break;
 		}
 
@@ -605,9 +600,7 @@ public class RangerAdminJersey2RESTClient extends AbstractRangerAdminClient {
 
 		final ServicePolicies ret;
 
-		final UserGroupInformation user         = MiscUtil.getUGILoginUser();
-		final boolean              isSecureMode = isKerberosEnabled(user);
-		final Response 	           response     = getRangerAdminPolicyDownloadResponse(lastKnownVersion, lastActivationTimeInMillis, user, isSecureMode);
+		final Response 	           response     = getRangerAdminPolicyDownloadResponse(lastKnownVersion, lastActivationTimeInMillis);
 
 		int httpResponseCode = response == null ? -1 : response.getStatus();
 		String body = null;
@@ -656,7 +649,7 @@ public class RangerAdminJersey2RESTClient extends AbstractRangerAdminClient {
 				policyDownloadSessionId = null;
 				isValidPolicyDownloadSessionCookie = false;
 				body = response.readEntity(String.class);
-				LOG.warn(String.format("Unexpected: Received status[%d] with body[%s] form url[%s]", httpResponseCode, body, getRelativeURL(isSecureMode)));
+				LOG.warn(String.format("Unexpected: Received status[%d] with body[%s] form url[%s]", httpResponseCode, body, getRelativeURL(isSecureMode())));
 				break;
 		}
 
@@ -667,7 +660,7 @@ public class RangerAdminJersey2RESTClient extends AbstractRangerAdminClient {
 		return ret;
 	}
 
-	private Response getRangerAdminPolicyDownloadResponse(final long lastKnownVersion, final long lastActivationTimeInMillis, final UserGroupInformation user, final boolean isSecureMode) throws Exception {
+	private Response getRangerAdminPolicyDownloadResponse(final long lastKnownVersion, final long lastActivationTimeInMillis) throws Exception {
 		if (LOG.isDebugEnabled()) {
 			LOG.debug("==> RangerAdminJersey2RESTClient.getRangerAdminPolicyDownloadResponse(" + lastKnownVersion + ", " + lastActivationTimeInMillis + ")");
 		}
@@ -682,23 +675,16 @@ public class RangerAdminJersey2RESTClient extends AbstractRangerAdminClient {
 		queryParams.put(RangerRESTUtils.REST_PARAM_SUPPORTS_POLICY_DELTAS, Boolean.toString(_supportsPolicyDeltas));
 		queryParams.put(RangerRESTUtils.REST_PARAM_CAPABILITIES, pluginCapabilities);
 
-		final String relativeURL = getRelativeURL(isSecureMode);
-
-		if (isSecureMode) {
+		if (isSecureMode()) {
 			if (LOG.isDebugEnabled()) {
-				LOG.debug("Checking Service policy if updated as user : " + user);
+				LOG.debug("Checking Service policy if updated as user : " + MiscUtil.getUGILoginUser());
 			}
-			PrivilegedAction<Response> action = new PrivilegedAction<Response>() {
-				public Response run() {
-					return get(queryParams, relativeURL, policyDownloadSessionId);
-				}
-			};
-			ret = user.doAs(action);
+			ret = MiscUtil.executePrivilegedAction((PrivilegedExceptionAction<Response>) () -> get(queryParams, getRelativeURL(true), policyDownloadSessionId));
 		} else {
 			if (LOG.isDebugEnabled()) {
 				LOG.debug("Checking Service policy if updated with old api call");
 			}
-			ret = get(queryParams, relativeURL, policyDownloadSessionId);
+			ret = get(queryParams, getRelativeURL(false), policyDownloadSessionId);
 		}
 
 		if (LOG.isDebugEnabled()) {
@@ -755,9 +741,7 @@ public class RangerAdminJersey2RESTClient extends AbstractRangerAdminClient {
 
 		final ServiceTags ret;
 
-		final UserGroupInformation user         = MiscUtil.getUGILoginUser();
-		final boolean              isSecureMode = isKerberosEnabled(user);
-		final Response             response     = getTagsDownloadResponse(lastKnownVersion, lastActivationTimeInMillis, user, isSecureMode);
+		final Response response  = getTagsDownloadResponse(lastKnownVersion, lastActivationTimeInMillis);
 
 		int httpResponseCode = response == null ? -1 : response.getStatus();
 		String body = null;
@@ -803,7 +787,7 @@ public class RangerAdminJersey2RESTClient extends AbstractRangerAdminClient {
 				ret = null;
 				tagDownloadSessionId = null;
 				body = response.readEntity(String.class);
-				LOG.warn(String.format("Unexpected: Received status[%d] with body[%s] form url[%s]", httpResponseCode, body, getRelativeURLForTagDownload(isSecureMode)));
+				LOG.warn(String.format("Unexpected: Received status[%d] with body[%s] form url[%s]", httpResponseCode, body, getRelativeURLForTagDownload(isSecureMode())));
 				break;
 		}
 
@@ -821,9 +805,7 @@ public class RangerAdminJersey2RESTClient extends AbstractRangerAdminClient {
 
 		final ServiceTags ret;
 
-		final UserGroupInformation user = MiscUtil.getUGILoginUser();
-		final boolean isSecureMode = isKerberosEnabled(user);
-		final Response response = getTagsDownloadResponse(lastKnownVersion, lastActivationTimeInMillis, user, isSecureMode);
+		final Response response = getTagsDownloadResponse(lastKnownVersion, lastActivationTimeInMillis);
 
 		int httpResponseCode = response == null ? -1 : response.getStatus();
 		String body = null;
@@ -883,7 +865,7 @@ public class RangerAdminJersey2RESTClient extends AbstractRangerAdminClient {
 		return ret;
 	}
 
-	private Response getTagsDownloadResponse(final long lastKnownVersion, final long lastActivationTimeInMillis, final UserGroupInformation user, final boolean isSecureMode) throws Exception {
+	private Response getTagsDownloadResponse(final long lastKnownVersion, final long lastActivationTimeInMillis) throws Exception {
 		if (LOG.isDebugEnabled()) {
 			LOG.debug("==> RangerAdminJersey2RESTClient.getTagsDownloadResponse(" + lastKnownVersion + ", " + lastActivationTimeInMillis + ")");
 		}
@@ -897,23 +879,16 @@ public class RangerAdminJersey2RESTClient extends AbstractRangerAdminClient {
 		queryParams.put(RangerRESTUtils.REST_PARAM_SUPPORTS_TAG_DELTAS, Boolean.toString(_supportsTagDeltas));
 		queryParams.put(RangerRESTUtils.REST_PARAM_CAPABILITIES, pluginCapabilities);
 
-		final String relativeURL = getRelativeURLForTagDownload(isSecureMode);
-
-		if (isSecureMode) {
+		if (isSecureMode()) {
 			if (LOG.isDebugEnabled()) {
-				LOG.debug("Checking Service tags if updated as user : " + user);
+				LOG.debug("Checking Service tags if updated as user : " + MiscUtil.getUGILoginUser());
 			}
-			PrivilegedAction<Response> action = new PrivilegedAction<Response>() {
-				public Response run() {
-					return get(queryParams, relativeURL, tagDownloadSessionId);
-				}
-			};
-			ret = user.doAs(action);
+			ret = MiscUtil.executePrivilegedAction((PrivilegedExceptionAction<Response>) () -> get(queryParams, getRelativeURLForTagDownload(true), tagDownloadSessionId));
 		} else {
 			if (LOG.isDebugEnabled()) {
 				LOG.debug("Checking Service tags if updated with old api call");
 			}
-			ret = get(queryParams, relativeURL, tagDownloadSessionId);
+			ret = get(queryParams, getRelativeURLForTagDownload(false), tagDownloadSessionId);
 		}
 
 		if (LOG.isDebugEnabled()) {
@@ -969,9 +944,7 @@ public class RangerAdminJersey2RESTClient extends AbstractRangerAdminClient {
 
 		final RangerRoles ret;
 
-		final UserGroupInformation user         = MiscUtil.getUGILoginUser();
-		final boolean              isSecureMode = isKerberosEnabled(user);
-		final Response             response     = getRoleDownloadResponse(lastKnownRoleVersion, lastActivationTimeInMillis, user, isSecureMode);
+		final Response response = getRoleDownloadResponse(lastKnownRoleVersion, lastActivationTimeInMillis);
 
 		int httpResponseCode = response == null ? -1 : response.getStatus();
 		String body = null;
@@ -1017,7 +990,7 @@ public class RangerAdminJersey2RESTClient extends AbstractRangerAdminClient {
 				ret = null;
 				roleDownloadSessionId = null;
 				body = response.readEntity(String.class);
-				LOG.warn(String.format("Unexpected: Received status[%d] with body[%s] form url[%s]", httpResponseCode, body, getRelativeURLForRoleDownload(isSecureMode)));
+				LOG.warn(String.format("Unexpected: Received status[%d] with body[%s] form url[%s]", httpResponseCode, body, getRelativeURLForRoleDownload(isSecureMode())));
 				break;
 		}
 
@@ -1035,9 +1008,7 @@ public class RangerAdminJersey2RESTClient extends AbstractRangerAdminClient {
 
 		final RangerRoles ret;
 
-		final UserGroupInformation user = MiscUtil.getUGILoginUser();
-		final boolean isSecureMode = isKerberosEnabled(user);
-		final Response response = getRoleDownloadResponse(lastKnownRoleVersion, lastActivationTimeInMillis, user, isSecureMode);
+		final Response response = getRoleDownloadResponse(lastKnownRoleVersion, lastActivationTimeInMillis);
 
 		int httpResponseCode = response == null ? -1 : response.getStatus();
 		String body = null;
@@ -1085,7 +1056,7 @@ public class RangerAdminJersey2RESTClient extends AbstractRangerAdminClient {
 				roleDownloadSessionId = null;
 				isValidRoleDownloadSessionCookie = false;
 				body = response.readEntity(String.class);
-				LOG.warn(String.format("Unexpected: Received status[%d] with body[%s] form url[%s]", httpResponseCode, body, getRelativeURLForRoleDownload(isSecureMode)));
+				LOG.warn(String.format("Unexpected: Received status[%d] with body[%s] form url[%s]", httpResponseCode, body, getRelativeURLForRoleDownload(isSecureMode())));
 				break;
 		}
 
@@ -1096,7 +1067,7 @@ public class RangerAdminJersey2RESTClient extends AbstractRangerAdminClient {
 		return ret;
 	}
 
-	private Response getRoleDownloadResponse(final long lastKnownRoleVersion, final long lastActivationTimeInMillis, final UserGroupInformation user, final boolean isSecureMode) throws Exception {
+	private Response getRoleDownloadResponse(final long lastKnownRoleVersion, final long lastActivationTimeInMillis) throws Exception {
 		if (LOG.isDebugEnabled()) {
 			LOG.debug("==> RangerAdminJersey2RESTClient.getRoleDownloadResponse(" + lastKnownRoleVersion + ", " + lastActivationTimeInMillis + ")");
 		}
@@ -1109,23 +1080,16 @@ public class RangerAdminJersey2RESTClient extends AbstractRangerAdminClient {
 		queryParams.put(RangerRESTUtils.REST_PARAM_PLUGIN_ID, _pluginId);
 		queryParams.put(RangerRESTUtils.REST_PARAM_CLUSTER_NAME, _clusterName);
 
-		final String relativeURL = getRelativeURLForRoleDownload(isSecureMode);
-
-		if (isSecureMode) {
+		if (isSecureMode()) {
 			if (LOG.isDebugEnabled()) {
-				LOG.debug("Checking Roles if updated as user : " + user);
+				LOG.debug("Checking Roles if updated as user : " + MiscUtil.getUGILoginUser());
 			}
-			PrivilegedAction<Response> action = new PrivilegedAction<Response>() {
-				public Response run() {
-					return get(queryParams, relativeURL, roleDownloadSessionId);
-				}
-			};
-			ret = user.doAs(action);
+			ret = MiscUtil.executePrivilegedAction((PrivilegedExceptionAction<Response>) () -> get(queryParams, getRelativeURLForRoleDownload(true), roleDownloadSessionId));
 		} else {
 			if (LOG.isDebugEnabled()) {
 				LOG.debug("Checking Roles if updated with old api call");
 			}
-			ret = get(queryParams, relativeURL, roleDownloadSessionId);
+			ret = get(queryParams, getRelativeURLForRoleDownload(false), roleDownloadSessionId);
 		}
 
 		if (LOG.isDebugEnabled()) {
@@ -1198,4 +1162,8 @@ public class RangerAdminJersey2RESTClient extends AbstractRangerAdminClient {
 
 		return ret;
 	}
+
+	private boolean isSecureMode() {
+		return isKerberosEnabled(MiscUtil.getUGILoginUser());
+	}
 }
