@@ -25,6 +25,7 @@ import java.net.ServerSocket;
 import java.nio.file.Files;
 import java.nio.file.Path;
 import java.security.KeyStore;
+import java.time.Duration;
 import java.util.Arrays;
 import java.util.Properties;
 import java.util.concurrent.Future;
@@ -43,10 +44,12 @@ import org.apache.kafka.clients.producer.ProducerRecord;
 import org.apache.kafka.clients.producer.RecordMetadata;
 import org.apache.kafka.common.config.SslConfigs;
 import org.apache.kafka.common.utils.Time;
-import org.junit.Assert;
-import org.junit.Test;
+import org.junit.jupiter.api.Assertions;
+import org.junit.jupiter.api.Test;
 
 import kafka.server.KafkaConfig;
+import org.junit.jupiter.api.AfterAll;
+import org.junit.jupiter.api.BeforeAll;
 import scala.Some;
 
 /**
@@ -75,7 +78,7 @@ public class KafkaRangerAuthorizerTest {
     private static String truststorePath;
     private static Path tempDir;
     
-    @org.junit.BeforeClass
+    @BeforeAll
     public static void setup() throws Exception {
     	// Create keys
         String serviceDN = "CN=localhost,O=Apache,L=Dublin,ST=Leinster,C=IE";
@@ -100,20 +103,20 @@ public class KafkaRangerAuthorizerTest {
     			
         zkServer = new TestingServer();
 		zkServer.start() ;
-
+        
         // Get a random port
-		try (ServerSocket serverSocket = new ServerSocket(0)) {
-			Assert.assertNotNull(serverSocket) ;
+        try (ServerSocket serverSocket = new ServerSocket(0)) {
+			Assertions.assertNotNull(serverSocket) ;
 			port = serverSocket.getLocalPort() ;
-			Assert.assertTrue(port > 0) ;
+			Assertions.assertTrue(port > 0) ;
 		} catch (java.io.IOException e) {
 			throw new RuntimeException("Local socket port not available", e) ;
 		}
 
         tempDir = Files.createTempDirectory("kafka");
-        
+
         final Properties props = new Properties();
-        props.put("broker.id", String.valueOf(1)) ;
+        props.put("broker.id", String.valueOf(1));
         props.put("host.name", "localhost");
         props.put("port", String.valueOf(port));
         props.put("log.dir", tempDir.toString());
@@ -156,7 +159,7 @@ public class KafkaRangerAuthorizerTest {
         KafkaTestUtils.createSomeTopics(adminProps);
     }
     
-    @org.junit.AfterClass
+    @AfterAll
     public static void cleanup() throws Exception {
         if (kafkaServer != null) {
             kafkaServer.shutdown();
@@ -199,8 +202,6 @@ public class KafkaRangerAuthorizerTest {
         producerProps.put(SslConfigs.SSL_TRUSTSTORE_LOCATION_CONFIG, truststorePath);
         producerProps.put(SslConfigs.SSL_TRUSTSTORE_PASSWORD_CONFIG, "security");
         
-        final Producer<String, String> producer = new KafkaProducer<>(producerProps);
-        
         // Create the Consumer
         Properties consumerProps = new Properties();
         consumerProps.put("bootstrap.servers", "localhost:" + port);
@@ -218,31 +219,30 @@ public class KafkaRangerAuthorizerTest {
         consumerProps.put(SslConfigs.SSL_KEY_PASSWORD_CONFIG, "ckpass");
         consumerProps.put(SslConfigs.SSL_TRUSTSTORE_LOCATION_CONFIG, truststorePath);
         consumerProps.put(SslConfigs.SSL_TRUSTSTORE_PASSWORD_CONFIG, "security");
-        
-        final KafkaConsumer<String, String> consumer = new KafkaConsumer<>(consumerProps);
-        consumer.subscribe(Arrays.asList("test"));
-        
-        // Send a message
-        producer.send(new ProducerRecord<String, String>("test", "somekey", "somevalue"));
-        producer.flush();
-        
-        // Poll until we consume it
-        
-        ConsumerRecord<String, String> record = null;
-        for (int i = 0; i < 1000; i++) {
-            ConsumerRecords<String, String> records = consumer.poll(100);
-            if (records.count() > 0) {
-                record = records.iterator().next();
-                break;
+
+        try (KafkaConsumer<String, String> consumer = new KafkaConsumer<>(consumerProps)) {
+            consumer.subscribe(Arrays.asList("test"));
+
+            try (Producer<String, String> producer = new KafkaProducer<>(producerProps)) {
+                // Send a message
+                producer.send(new ProducerRecord<>("test", "somekey", "somevalue"));
+                producer.flush();
             }
-            Thread.sleep(1000);
+
+            // Poll until we consume it
+            ConsumerRecord<String, String> record = null;
+            for (int i = 0; i < 1000; i++) {
+                ConsumerRecords<String, String> records = consumer.poll(Duration.ofMillis(100));
+                if (records.count() > 0) {
+                    record = records.iterator().next();
+                    break;
+                }
+                Thread.sleep(1000);
+            }
+
+            Assertions.assertNotNull(record);
+            Assertions.assertEquals("somevalue", record.value());
         }
-
-        Assert.assertNotNull(record);
-        Assert.assertEquals("somevalue", record.value());
-
-        producer.close();
-        consumer.close();
     }
     
     // The "IT" group can write to any topic
@@ -261,15 +261,13 @@ public class KafkaRangerAuthorizerTest {
         producerProps.put(SslConfigs.SSL_KEY_PASSWORD_CONFIG, "skpass");
         producerProps.put(SslConfigs.SSL_TRUSTSTORE_LOCATION_CONFIG, truststorePath);
         producerProps.put(SslConfigs.SSL_TRUSTSTORE_PASSWORD_CONFIG, "security");
-        
-        final Producer<String, String> producer = new KafkaProducer<>(producerProps);
-        // Send a message
-        Future<RecordMetadata> record = 
-            producer.send(new ProducerRecord<String, String>("dev", "somekey", "somevalue"));
-        producer.flush();
-        record.get();
 
-        producer.close();
+        try (Producer<String, String> producer = new KafkaProducer<>(producerProps)) {
+            // Send a message
+            Future<RecordMetadata> record = producer.send(new ProducerRecord<>("dev", "somekey", "somevalue"));
+            producer.flush();
+            record.get();
+        }
     }
     
     // The "public" group can write to "test" but not "dev"
@@ -288,24 +286,22 @@ public class KafkaRangerAuthorizerTest {
         producerProps.put(SslConfigs.SSL_KEY_PASSWORD_CONFIG, "ckpass");
         producerProps.put(SslConfigs.SSL_TRUSTSTORE_LOCATION_CONFIG, truststorePath);
         producerProps.put(SslConfigs.SSL_TRUSTSTORE_PASSWORD_CONFIG, "security");
-        
-        final Producer<String, String> producer = new KafkaProducer<>(producerProps);
-        
-        // Send a message
-        Future<RecordMetadata> record =
-            producer.send(new ProducerRecord<String, String>("test", "somekey", "somevalue"));
-        producer.flush();
-        record.get();
-        
-        try {
-            record = producer.send(new ProducerRecord<String, String>("dev", "somekey", "somevalue"));
+
+        try (Producer<String, String> producer = new KafkaProducer<>(producerProps)) {
+            // Send a message
+            Future<RecordMetadata> record =
+                producer.send(new ProducerRecord<>("test", "somekey", "somevalue"));
             producer.flush();
             record.get();
-        } catch (Exception ex) {
-            Assert.assertTrue(ex.getMessage().contains("Not authorized to access topics"));
+
+            try {
+                record = producer.send(new ProducerRecord<>("dev", "somekey", "somevalue"));
+                producer.flush();
+                record.get();
+            } catch (Exception ex) {
+                Assertions.assertTrue(ex.getMessage().contains("Not authorized to access topics"));
+            }
         }
-        
-        producer.close();
     }
 
     // The "public" group can read from "messages"
@@ -325,8 +321,6 @@ public class KafkaRangerAuthorizerTest {
         producerProps.put(SslConfigs.SSL_TRUSTSTORE_LOCATION_CONFIG, truststorePath);
         producerProps.put(SslConfigs.SSL_TRUSTSTORE_PASSWORD_CONFIG, "security");
 
-        final Producer<String, String> producer = new KafkaProducer<>(producerProps);
-
         // Create the Consumer
         Properties consumerProps = new Properties();
         consumerProps.put("bootstrap.servers", "localhost:" + port);
@@ -345,30 +339,29 @@ public class KafkaRangerAuthorizerTest {
         consumerProps.put(SslConfigs.SSL_TRUSTSTORE_LOCATION_CONFIG, truststorePath);
         consumerProps.put(SslConfigs.SSL_TRUSTSTORE_PASSWORD_CONFIG, "security");
 
-        final KafkaConsumer<String, String> consumer = new KafkaConsumer<>(consumerProps);
-        consumer.subscribe(Arrays.asList("messages"));
+        try (KafkaConsumer<String, String> consumer = new KafkaConsumer<>(consumerProps)) {
+            consumer.subscribe(Arrays.asList("messages"));
 
-        // Send a message
-        producer.send(new ProducerRecord<String, String>("messages", "somekey", "somevalue"));
-        producer.flush();
-
-        // Poll until we consume it
-
-        ConsumerRecord<String, String> record = null;
-        for (int i = 0; i < 1000; i++) {
-            ConsumerRecords<String, String> records = consumer.poll(100);
-            if (records.count() > 0) {
-                record = records.iterator().next();
-                break;
+            try (Producer<String, String> producer = new KafkaProducer<>(producerProps)) {
+                // Send a message
+                producer.send(new ProducerRecord<>("messages", "somekey", "somevalue"));
+                producer.flush();
             }
-            Thread.sleep(1000);
+
+            // Poll until we consume it
+            ConsumerRecord<String, String> record = null;
+            for (int i = 0; i < 1000; i++) {
+                ConsumerRecords<String, String> records = consumer.poll(100);
+                if (records.count() > 0) {
+                    record = records.iterator().next();
+                    break;
+                }
+                Thread.sleep(1000);
+            }
+
+            Assertions.assertNotNull(record);
+            Assertions.assertEquals("somevalue", record.value());
         }
-
-        Assert.assertNotNull(record);
-        Assert.assertEquals("somevalue", record.value());
-
-        producer.close();
-        consumer.close();
     }
 
 }
