@@ -410,9 +410,9 @@ public class RangerSolrAuthorizer extends SearchComponent implements Authorizati
 
 	@Override
 	public void prepare(ResponseBuilder rb) throws IOException {
-		if (!enabled) {
+		if (solrPlugin == null || !enabled) {
 			if (logger.isDebugEnabled()) {
-				logger.debug("Solr Document level Authorization is not enabled!");
+				logger.debug("Solr Ranger Authorization or Solr Document level Authorization is not enabled!");
 			}
 			return;
 		}
@@ -708,7 +708,7 @@ public class RangerSolrAuthorizer extends SearchComponent implements Authorizati
 		if (roles != null && !roles.isEmpty()) {
 			StringBuilder builder = new StringBuilder();
 			for (String role : roles) {
-				addDisjunctiveRawClause(builder, role);
+				addDisjunctiveRawClause(builder, "\"" + role + "\"");
 			}
 			if (allRolesToken != null && !allRolesToken.isEmpty()) {
 				addDisjunctiveRawClause(builder, allRolesToken);
