@@ -25,8 +25,8 @@ import org.apache.commons.cli.HelpFormatter;
 import org.apache.commons.cli.Options;
 
 import org.apache.commons.lang.StringUtils;
-import org.apache.commons.logging.Log;
-import org.apache.commons.logging.LogFactory;
+import org.slf4j.Logger;
+import org.slf4j.LoggerFactory;
 
 import java.io.File;
 import java.io.FileInputStream;
@@ -38,7 +38,7 @@ import java.util.Arrays;
 
 public class CommandLineParser
 {
-    static final Log LOG      = LogFactory.getLog(CommandLineParser.class);
+    static final Logger LOG      = LoggerFactory.getLogger(CommandLineParser.class);
 
     private String servicePoliciesFileName;
     private String[] requestFileNames;
@@ -52,7 +52,6 @@ public class CommandLineParser
     private int concurrentClientCount = 1;
     private int iterationsCount = 1;
 
-    private boolean isDynamicReorderingDisabled = true;
     private boolean isTrieLookupPrefixDisabled = true;
 
     private boolean isLazyTriePostSetupDisabled = true;
@@ -69,7 +68,7 @@ public class CommandLineParser
         PerfTestOptions ret = null;
         if (parseArguments(args) && validateInputFiles()) {
             // Instantiate a data-object and return
-            ret = new PerfTestOptions(servicePoliciesFileURL, requestFileURLs, statCollectionFileURL, concurrentClientCount, iterationsCount, isDynamicReorderingDisabled, isTrieLookupPrefixDisabled, isLazyTriePostSetupDisabled, configurationFileURL);
+            ret = new PerfTestOptions(servicePoliciesFileURL, requestFileURLs, statCollectionFileURL, concurrentClientCount, iterationsCount, isTrieLookupPrefixDisabled, isLazyTriePostSetupDisabled, configurationFileURL);
         } else {
             showUsage();
         }
@@ -85,7 +84,6 @@ public class CommandLineParser
             -n number-of-iterations
             -p modules-to-collect-stats
             -f configuration-file-name
-            -o
             -t
             -d
 
@@ -108,7 +106,6 @@ public class CommandLineParser
         options.addOption("c", "clients", true, "Number of concurrent clients");
         options.addOption("n", "cycles", true, "Number of iterations");
         options.addOption("f", "configurations", true, "Configuration File Name");
-        options.addOption("o", "optimize", false, "Enable usage-based policy reordering");
         options.addOption("t", "trie-prefilter", false, "Enable trie-prefilter");
         options.addOption("d", "trie-lazy-setup", false, "Enable lazy trie-setup");
 
@@ -138,9 +135,6 @@ public class CommandLineParser
             if (iterationsOptionValue != null) {
                 iterationsCount = Integer.parseInt(iterationsOptionValue);
             }
-            if (commandLine.hasOption("o")) {
-                isDynamicReorderingDisabled = false;
-            }
             if (commandLine.hasOption("t")) {
                 isTrieLookupPrefixDisabled = false;
             }
@@ -154,7 +148,6 @@ public class CommandLineParser
             if (LOG.isDebugEnabled()) {
                 LOG.debug("servicePoliciesFileName=" + servicePoliciesFileName + ", requestFileName=" + Arrays.toString(requestFileNames));
                 LOG.debug("concurrentClientCount=" + concurrentClientCount + ", iterationsCount=" + iterationsCount);
-                LOG.debug("isDynamicReorderingDisabled=" + isDynamicReorderingDisabled);
                 LOG.debug("isTrieLookupPrefixDisabled=" + isTrieLookupPrefixDisabled);
                 LOG.debug("isLazyTriePostSetupDisabled=" + isLazyTriePostSetupDisabled);
                 LOG.debug("configurationFileName=" + configurationFileName);
