@@ -19,11 +19,7 @@
 
  package org.apache.ranger.common;
 
-import java.util.ArrayList;
-import java.util.Date;
-import java.util.HashMap;
-import java.util.List;
-import java.util.Map;
+import java.util.*;
 
 import javax.annotation.Nonnull;
 import javax.persistence.EntityManager;
@@ -42,7 +38,13 @@ import org.springframework.stereotype.Component;
 @Component
 public class RangerSearchUtil extends SearchUtil {
 	final static Logger logger = LoggerFactory.getLogger(RangerSearchUtil.class);
-	
+
+	int dbMinInListLength = 20;
+
+	public RangerSearchUtil() {
+		dbMinInListLength = PropertiesUtil.getIntProperty("ranger.db.min_inlist", dbMinInListLength);
+	}
+
 	public SearchFilter getSearchFilter(@Nonnull HttpServletRequest request, List<SortField> sortFields) {
 		Validate.notNull(request, "request");
 		SearchFilter ret = new SearchFilter();
@@ -88,6 +90,22 @@ public class RangerSearchUtil extends SearchUtil {
 		ret.setParam(SearchFilter.CLUSTER_NAME, request.getParameter(SearchFilter.CLUSTER_NAME));
 		ret.setParam(SearchFilter.FETCH_ZONE_UNZONE_POLICIES, request.getParameter(SearchFilter.FETCH_ZONE_UNZONE_POLICIES));
 		ret.setParam(SearchFilter.FETCH_TAG_POLICIES, request.getParameter(SearchFilter.FETCH_TAG_POLICIES));
+		ret.setParam(SearchFilter.SERVICE_NAME_PREFIX, request.getParameter(SearchFilter.SERVICE_NAME_PREFIX));
+		ret.setParam(SearchFilter.ZONE_NAME_PREFIX, request.getParameter(SearchFilter.ZONE_NAME_PREFIX));
+		ret.setParam(SearchFilter.TAG_TYPE, request.getParameter(SearchFilter.TAG_TYPE));
+		ret.setParam(SearchFilter.TAG_TYPE_PARTIAL, request.getParameter(SearchFilter.TAG_TYPE_PARTIAL));
+		ret.setParam(SearchFilter.TAG_SOURCE, request.getParameter(SearchFilter.TAG_SOURCE));
+		ret.setParam(SearchFilter.TAG_SOURCE_PARTIAL, request.getParameter(SearchFilter.TAG_SOURCE_PARTIAL));
+		ret.setParam(SearchFilter.TAG_SERVICE_NAME, request.getParameter(SearchFilter.TAG_SERVICE_NAME));
+		ret.setParam(SearchFilter.TAG_SERVICE_NAME_PARTIAL, request.getParameter(SearchFilter.TAG_SERVICE_NAME_PARTIAL));
+		ret.setParam(SearchFilter.TAG_RESOURCE_GUID, request.getParameter(SearchFilter.TAG_RESOURCE_GUID));
+		ret.setParam(SearchFilter.TAG_RESOURCE_SIGNATURE, request.getParameter(SearchFilter.TAG_RESOURCE_SIGNATURE));
+		ret.setParam(SearchFilter.TAG_RESOURCE_ELEMENTS, request.getParameter(SearchFilter.TAG_RESOURCE_ELEMENTS));
+		ret.setParam(SearchFilter.TAG_DEF_GUID, request.getParameter(SearchFilter.TAG_DEF_GUID));
+		ret.setParam(SearchFilter.TAG_DEF_ID, request.getParameter(SearchFilter.TAG_DEF_ID));
+		ret.setParam(SearchFilter.TAG_ID, request.getParameter(SearchFilter.TAG_ID));
+		ret.setParam(SearchFilter.CREATED_BY, request.getParameter(SearchFilter.CREATED_BY));
+
 		for (Map.Entry<String, String[]> e : request.getParameterMap().entrySet()) {
 			String name = e.getKey();
 			String[] values = e.getValue();
@@ -182,30 +200,39 @@ public class RangerSearchUtil extends SearchUtil {
 				MessageEnums.INVALID_INPUT_DATA, null, SearchFilter.PAGE_SIZE);
 		ret.setMaxRows(validatePageSize(pageSize));
 
+		if (request.getParameter(SearchFilter.POLICY_TYPE) != null) {
+			int policyType = restErrorUtil.parseInt(request.getParameter(SearchFilter.POLICY_TYPE), 0,
+					"Invalid value for parameter policyType", MessageEnums.INVALID_INPUT_DATA, null,
+					SearchFilter.POLICY_TYPE);
+			ret.setParam(SearchFilter.POLICY_TYPE, Integer.toString(policyType));
+		}
+
 		ret.setGetCount(restErrorUtil.parseBoolean(request.getParameter("getCount"), true));
 		String sortBy = restErrorUtil.validateString(request.getParameter(SearchFilter.SORT_BY),
 				StringUtil.VALIDATION_ALPHA, "Invalid value for parameter sortBy", MessageEnums.INVALID_INPUT_DATA,
 				null, SearchFilter.SORT_BY);
 
-		boolean sortSet = false;
 		if (!StringUtils.isEmpty(sortBy)) {
+			boolean sortSet = false;
+
 			for (SortField sortField : sortFields) {
 				if (sortField.getParamName().equalsIgnoreCase(sortBy)) {
 					ret.setSortBy(sortField.getParamName());
-					String sortType = restErrorUtil.validateString(request.getParameter("sortType"),
-							StringUtil.VALIDATION_ALPHA, "Invalid value for parameter sortType",
-							MessageEnums.INVALID_INPUT_DATA, null, "sortType");
-					ret.setSortType(sortType);
 					sortSet = true;
 					break;
 				}
 			}
+
+			if (!sortSet) {
+				logger.info("Invalid or unsupported sortBy field passed. sortBy=" + sortBy, new Throwable());
+			}
 		}
 
-		if (!sortSet && !StringUtils.isEmpty(sortBy)) {
-			logger.info("Invalid or unsupported sortBy field passed. sortBy=" + sortBy, new Throwable());
-		}
-		
+		String sortType = restErrorUtil.validateString(request.getParameter("sortType"),
+				StringUtil.VALIDATION_ALPHA, "Invalid value for parameter sortType",
+				MessageEnums.INVALID_INPUT_DATA, null, "sortType");
+		ret.setSortType(sortType);
+
 		if(ret.getParams() == null) {
 			ret.setParams(new HashMap<String, String>());
 		}
@@ -254,7 +281,100 @@ public class RangerSearchUtil extends SearchUtil {
 				continue;
 			}
 
-			if (searchField.getDataType() == SearchField.DATA_TYPE.INTEGER) {
+			Object[] multiValue   = searchCriteria.getMultiValueParam(searchField.getClientFieldName());
+			boolean  isMultiValue = multiValue != null && multiValue.length > 0;
+
+			if (searchField.getDataType() == SearchField.DATA_TYPE.INT_LIST || (isMultiValue && searchField.getDataType() == SearchField.DATA_TYPE.INTEGER)) {
+				List<Number> intValueList = new ArrayList<>();
+
+				if (isMultiValue) {
+					for (Object value : multiValue) {
+						if (value instanceof Integer || value instanceof Long) {
+							intValueList.add((Number) value);
+						} else if (value != null) {
+							intValueList.add(restErrorUtil.parseInt(value.toString(), "Invalid value for " + searchField.getClientFieldName(), MessageEnums.INVALID_INPUT_DATA, null, searchField.getClientFieldName()));
+						}
+					}
+				} else {
+					String paramVal = searchCriteria.getParam(searchField.getClientFieldName());
+
+					if (paramVal != null) {
+						intValueList.add(restErrorUtil.parseInt(paramVal, "Invalid value for " + searchField.getClientFieldName(), MessageEnums.INVALID_INPUT_DATA, null, searchField.getClientFieldName()));
+					}
+				}
+
+				if (!intValueList.isEmpty()) {
+					if (searchField.getCustomCondition() == null) {
+						if (intValueList.size() <= dbMinInListLength) {
+							whereClause.append(" and ");
+
+							if (intValueList.size() > 1) {
+								whereClause.append(" ( ");
+							}
+
+							for (int count = 0; count < intValueList.size(); count++) {
+								if (count > 0) {
+									whereClause.append(" or ");
+								}
+
+								whereClause.append(searchField.getFieldName()).append("= :")
+								           .append(searchField.getClientFieldName()).append("_").append(count);
+							}
+
+							if (intValueList.size() > 1) {
+								whereClause.append(" ) ");
+							}
+
+						} else {
+							whereClause.append(" and ")
+							           .append(searchField.getFieldName())
+							           .append(" in ")
+							           .append(" (:").append(searchField.getClientFieldName()).append(")");
+						}
+					} else {
+						whereClause.append(" and ").append(searchField.getCustomCondition());
+					}
+				}
+			} else if (isMultiValue && searchField.getDataType() == SearchField.DATA_TYPE.STR_LIST) {
+				List<String> strValueList = new ArrayList<>();
+
+				for (Object value : multiValue) {
+					strValueList.add(String.valueOf(value));
+				}
+
+				if (!strValueList.isEmpty()) {
+					if (searchField.getCustomCondition() == null) {
+						if (strValueList.size() <= dbMinInListLength) {
+							whereClause.append(" and ");
+
+							if (strValueList.size() > 1) {
+								whereClause.append(" ( ");
+							}
+
+							for (int count = 0; count < strValueList.size(); count++) {
+								if (count > 0) {
+									whereClause.append(" or ");
+								}
+
+								whereClause.append(searchField.getFieldName()).append("= :")
+								           .append(searchField.getClientFieldName()).append("_").append(count);
+							}
+
+							if (strValueList.size() > 1) {
+								whereClause.append(" ) ");
+							}
+
+						} else {
+							whereClause.append(" and ")
+							           .append(searchField.getFieldName())
+							           .append(" in ")
+							           .append(" (:").append(searchField.getClientFieldName()).append(")");
+						}
+					} else {
+						whereClause.append(" and ").append(searchField.getCustomCondition());
+					}
+				}
+			} else if (searchField.getDataType() == SearchField.DATA_TYPE.INTEGER) {
 				Integer paramVal = restErrorUtil.parseInt(searchCriteria.getParam(searchField.getClientFieldName()),
 						"Invalid value for " + searchField.getClientFieldName(),
 						MessageEnums.INVALID_INPUT_DATA, null, searchField.getClientFieldName());
@@ -263,9 +383,9 @@ public class RangerSearchUtil extends SearchUtil {
 				if (intFieldValue != null) {
 					if (searchField.getCustomCondition() == null) {
 						whereClause.append(" and ")
-								.append(searchField.getFieldName())
-								.append("=:")
-								.append(searchField.getClientFieldName());
+						           .append(searchField.getFieldName())
+						           .append(getSqlOperator(searchField.getSearchType()))
+						           .append(":").append(searchField.getClientFieldName());
 					} else {
 						whereClause.append(" and ").append(searchField.getCustomCondition());
 					}
@@ -274,12 +394,9 @@ public class RangerSearchUtil extends SearchUtil {
 				String strFieldValue = searchCriteria.getParam(searchField.getClientFieldName());
 				if (strFieldValue != null) {
 					if (searchField.getCustomCondition() == null) {
-						whereClause.append(" and ").append("LOWER(").append(searchField.getFieldName()).append(")");
-						if (searchField.getSearchType() == SearchField.SEARCH_TYPE.FULL) {
-							whereClause.append("= :").append(searchField.getClientFieldName());
-						} else {
-							whereClause.append("like :").append(searchField.getClientFieldName());
-						}
+						whereClause.append(" and ").append("LOWER(").append(searchField.getFieldName()).append(")")
+						           .append(getSqlOperator(searchField.getSearchType()))
+						           .append(":").append(searchField.getClientFieldName());
 					} else {
 						whereClause.append(" and ").append(searchField.getCustomCondition());
 					}
@@ -292,9 +409,9 @@ public class RangerSearchUtil extends SearchUtil {
 				if (boolFieldValue != null) {
 					if (searchField.getCustomCondition() == null) {
 						whereClause.append(" and ")
-								.append(searchField.getFieldName())
-								.append("=:")
-								.append(searchField.getClientFieldName());
+						           .append(searchField.getFieldName())
+						           .append(getSqlOperator(searchField.getSearchType()))
+						           .append(":").append(searchField.getClientFieldName());
 					} else {
 						whereClause.append(" and ").append(searchField.getCustomCondition());
 					}
@@ -305,17 +422,9 @@ public class RangerSearchUtil extends SearchUtil {
 						null, searchField.getClientFieldName(), null);
 				if (fieldValue != null) {
 					if (searchField.getCustomCondition() == null) {
-						whereClause.append(" and ").append(searchField.getFieldName());
-						if (SearchField.SEARCH_TYPE.LESS_THAN.equals(searchField.getSearchType())) {
-							whereClause.append("< :");
-						} else if (SearchField.SEARCH_TYPE.LESS_EQUAL_THAN.equals(searchField.getSearchType())) {
-							whereClause.append("<= :");
-						} else if (SearchField.SEARCH_TYPE.GREATER_THAN.equals(searchField.getSearchType())) {
-							whereClause.append("> :");
-						} else if (SearchField.SEARCH_TYPE.GREATER_EQUAL_THAN.equals(searchField.getSearchType())) {
-							whereClause.append(">= :");
-						}
-						whereClause.append(searchField.getClientFieldName());
+						whereClause.append(" and ").append(searchField.getFieldName())
+						           .append(getSqlOperator(searchField.getSearchType()))
+						           .append(":").append(searchField.getClientFieldName());
 					} else {
 						whereClause.append(" and ").append(searchField.getCustomCondition());
 					}
@@ -339,10 +448,58 @@ public class RangerSearchUtil extends SearchUtil {
 	}
 	
 	protected void resolveQueryParams(Query query, SearchFilter searchCriteria, List<SearchField> searchFields) {
+		Map<String, String>   params           = searchCriteria.getParams();
+		Map<String, Object[]> multiValueParams = searchCriteria.getMultiValueParams();
 
 		for (SearchField searchField : searchFields) {
+			Object[] multiValue   = multiValueParams != null ? multiValueParams.get(searchField.getClientFieldName()) : null;
+			boolean  isMultiValue = multiValue != null && multiValue.length > 0;
 
-			if (searchField.getDataType() == SearchField.DATA_TYPE.INTEGER) {
+			if (searchField.getDataType() == SearchField.DATA_TYPE.INT_LIST || (isMultiValue && searchField.getDataType() == SearchField.DATA_TYPE.INTEGER)) {
+				List<Number> intValueList = new ArrayList<>();
+
+				if (isMultiValue) {
+					for (Object value : multiValue) {
+						if (value instanceof Integer || value instanceof Long) {
+							intValueList.add((Number) value);
+						} else if (value != null) {
+							intValueList.add(restErrorUtil.parseInt(value.toString(), "Invalid value for " + searchField.getClientFieldName(), MessageEnums.INVALID_INPUT_DATA, null, searchField.getClientFieldName()));
+						}
+					}
+				} else {
+					String paramVal = params != null ? params.get(searchField.getClientFieldName()) : null;
+
+					if (paramVal != null) {
+						intValueList.add(restErrorUtil.parseInt(paramVal, "Invalid value for " + searchField.getClientFieldName(), MessageEnums.INVALID_INPUT_DATA, null, searchField.getClientFieldName()));
+					}
+				}
+
+				if (!intValueList.isEmpty()) {
+					if (intValueList.size() <= dbMinInListLength) {
+						for (int idx = 0; idx < intValueList.size(); idx++) {
+							query.setParameter(searchField.getClientFieldName() + "_" + idx, intValueList.get(idx));
+						}
+					} else {
+						query.setParameter(searchField.getClientFieldName(), intValueList);
+					}
+				}
+			} else if (isMultiValue && searchField.getDataType() == SearchField.DATA_TYPE.STR_LIST) {
+				List<String> strValueList = new ArrayList<>();
+
+				for (Object value : multiValue) {
+					strValueList.add(String.valueOf(value));
+				}
+
+				if (!strValueList.isEmpty()) {
+					if (strValueList.size() <= dbMinInListLength) {
+						for (int idx = 0; idx < strValueList.size(); idx++) {
+							query.setParameter(searchField.getClientFieldName() + "_" + idx, strValueList.get(idx));
+						}
+					} else {
+						query.setParameter(searchField.getClientFieldName(), strValueList);
+					}
+				}
+			} else if (searchField.getDataType() == SearchField.DATA_TYPE.INTEGER) {
 				Integer paramVal = restErrorUtil.parseInt(searchCriteria.getParam(searchField.getClientFieldName()),
 						"Invalid value for " + searchField.getClientFieldName(),
 						MessageEnums.INVALID_INPUT_DATA, null, searchField.getClientFieldName());
@@ -387,11 +544,14 @@ public class RangerSearchUtil extends SearchUtil {
 	}
 	
 	public String constructSortClause(SearchFilter searchCriteria, List<SortField> sortFields) {
-		String sortBy = searchCriteria.getSortBy();
+		String ret         = null;
+		String sortBy      = searchCriteria.getSortBy();
+		String sortType    = getSortType(searchCriteria);
 		String querySortBy = null;
 		
 		if (!stringUtil.isEmpty(sortBy)) {
 			sortBy = sortBy.trim();
+
 			for (SortField sortField : sortFields) {
 				if (sortBy.equalsIgnoreCase(sortField.getParamName())) {
 					querySortBy = sortField.getFieldName();
@@ -408,31 +568,107 @@ public class RangerSearchUtil extends SearchUtil {
 					querySortBy = sortField.getFieldName();
 					// Override the sortBy using the default value
 					searchCriteria.setSortBy(sortField.getParamName());
-					searchCriteria.setSortType(sortField.getDefaultOrder().name());
+
+					if(sortType == null) {
+						sortType = sortField.getDefaultOrder().name();
+					}
+
+					searchCriteria.setSortType(sortType);
 					break;
 				}
 			}
 		}
 
 		if (querySortBy != null) {
-			String sortType = searchCriteria.getSortType();
-			String querySortType = "asc";
-			if (sortType != null) {
-				if ("asc".equalsIgnoreCase(sortType) || "desc".equalsIgnoreCase(sortType)) {
-					querySortType = sortType;
-				} else {
-					logger.error("Invalid sortType. sortType=" + sortType);
-				}
-			}
-			
-			if(querySortType!=null){
-				searchCriteria.setSortType(querySortType.toLowerCase());
-			}
-			String sortClause = " ORDER BY " + querySortBy + " " + querySortType;
+			String querySortType = stringUtil.isEmpty(sortType) ? RangerConstants.DEFAULT_SORT_ORDER : sortType;
 
-			return sortClause;
+			searchCriteria.setSortType(querySortType.toLowerCase());
+
+			ret = " ORDER BY " + querySortBy + " " + querySortType;
 		}
-		return null;
+
+		return ret;
+	}
+
+	private String getSortType(SearchFilter searchCriteria) {
+		String ret      = null;
+		String sortType = searchCriteria.getSortType();
+
+		if (!stringUtil.isEmpty(sortType)) {
+			if ("asc".equalsIgnoreCase(sortType) || "desc".equalsIgnoreCase(sortType)) {
+				ret = sortType;
+			} else {
+				logger.error("Invalid sortType. sortType=" + sortType);
+			}
+		}
+
+		return ret;
+	}
+
+	public void extractIntList(HttpServletRequest request, SearchFilter searchFilter, String paramName, String userFriendlyParamName) {
+		String[] values = getParamMultiValues(request, paramName);
+
+		if (values != null) {
+			List<Integer> intValues = new ArrayList<>(values.length);
+
+			for (String value : values) {
+				Integer intValue = restErrorUtil.parseInt(value, "Invalid value for " + userFriendlyParamName, MessageEnums.INVALID_INPUT_DATA, null, paramName);
+
+				intValues.add(intValue);
+			}
+
+			searchFilter.setMultiValueParam(paramName, intValues.toArray());
+		}
+	}
+
+	public void extractStringList(HttpServletRequest request, SearchFilter searchFilter, String paramName,
+			                      String userFriendlyParamName, String listName, String[] validValues, String regEx) {
+		String[] values = getParamMultiValues(request, paramName);
+
+		if (values != null) {
+			List<String> stringList = new ArrayList<>(values.length);
+
+			for (String value : values) {
+				if (!stringUtil.isEmpty(regEx)) {
+					restErrorUtil.validateString(value, regEx, "Invalid value for " + userFriendlyParamName, MessageEnums.INVALID_INPUT_DATA, null, paramName);
+				}
+
+				stringList.add(value);
+			}
+
+			searchFilter.setMultiValueParam(paramName, stringList.toArray());
+		}
+	}
+
+	public Map<String, String[]> getMultiValueParamsWithPrefix(HttpServletRequest request, String prefix, boolean stripPrefix) {
+		Map<String, String[]> ret = new HashMap<String, String[]>();
+		for (Map.Entry<String, String[]> e : request.getParameterMap().entrySet()) {
+			String name = e.getKey();
+			String[] values = e.getValue();
+
+			if (!StringUtils.isEmpty(name) && !ArrayUtils.isEmpty(values)
+					&& name.startsWith(prefix)) {
+	            if(stripPrefix) {
+					name = name.substring(prefix.length());
+				}
+	            ret.put(name, values);
+			}
+		}
+        return ret;
+	}
+
+	/**
+	 * @param request
+	 * @param paramName
+	 * @return
+	 */
+	String[] getParamMultiValues(HttpServletRequest request, String paramName) {
+		String[] values = request.getParameterValues(paramName);
+
+		if (values == null || values.length == 0) {
+			values = request.getParameterValues(paramName + "[]");
+		}
+
+		return values;
 	}
-	
 }
