@@ -22,6 +22,7 @@ import org.apache.commons.lang.StringUtils;
 import org.apache.ranger.authorization.utils.JsonUtils;
 import org.apache.ranger.biz.RangerBizUtil;
 import org.apache.ranger.biz.ServiceDBStore;
+import org.apache.ranger.biz.XUserMgr;
 import org.apache.ranger.common.GUIDUtil;
 import org.apache.ranger.common.JSONUtil;
 import org.apache.ranger.common.RangerValidatorFactory;
@@ -41,7 +42,13 @@ import org.apache.ranger.util.CLIUtil;
 import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
 import org.springframework.beans.factory.annotation.Autowired;
+import org.springframework.beans.factory.annotation.Qualifier;
 import org.springframework.stereotype.Component;
+import org.springframework.transaction.PlatformTransactionManager;
+import org.springframework.transaction.TransactionDefinition;
+import org.springframework.transaction.TransactionStatus;
+import org.springframework.transaction.support.TransactionCallback;
+import org.springframework.transaction.support.TransactionTemplate;
 
 import java.util.ArrayList;
 import java.util.Arrays;
@@ -96,6 +103,13 @@ public class PatchForKafkaServiceDefUpdate_J10033 extends BaseLoader {
 	@Autowired
 	ServiceDBStore svcStore;
 
+	@Autowired
+	XUserMgr xUserMgr;
+
+	@Autowired
+	@Qualifier(value = "transactionManager")
+	PlatformTransactionManager txManager;
+
 	public static void main(String[] args) {
 		logger.info("main()");
 		try {
@@ -348,12 +362,35 @@ public class PatchForKafkaServiceDefUpdate_J10033 extends BaseLoader {
 						continue;
 					}
 					XXUser xxUser = daoMgr.getXXUser().findByUserName(user);
+					Long userId = null;
 					if (xxUser == null) {
-						throw new RuntimeException(user + ": user does not exist. policy='" + xxPolicy.getName()
-								+ "' service='" + xxPolicy.getService() + "' user='" + user + "'");
+						if (null == xxUser) {
+							logger.info(user +" user is not found, adding user: "+user);
+							TransactionTemplate txTemplate = new TransactionTemplate(txManager);
+							txTemplate.setPropagationBehavior(TransactionDefinition.PROPAGATION_REQUIRES_NEW);
+							try {
+								txTemplate.execute(new TransactionCallback<Object>() {
+									@Override
+									public Object doInTransaction(TransactionStatus status) {
+										xUserMgr.createServiceConfigUserSynchronously(user);
+										return null;
+									}
+								});
+							} catch(Exception exception) {
+								logger.error("Cannot create ServiceConfigUser(" + user + ")", exception);
+							}
+						}
+
+						xxUser = daoMgr.getXXUser().findByUserName(user);
+						if (xxUser == null) {
+							throw new RuntimeException(user + ": user does not exist. policy='" + xxPolicy.getName()
+							+ "' service='" + xxPolicy.getService() + "' user='" + user + "'");
+						}
 					}
+					userId = xxUser.getId();
+
 					XXPolicyItemUserPerm xUserPerm = new XXPolicyItemUserPerm();
-					xUserPerm.setUserId(xxUser.getId());
+					xUserPerm.setUserId(userId);
 					xUserPerm.setPolicyItemId(createdXXPolicyItem.getId());
 					xUserPerm.setOrder(i);
 					xUserPerm.setAddedByUserId(currentUserId);
