@@ -18,13 +18,13 @@
 package org.apache.ranger.service;
 
 import java.util.ArrayList;
+import java.util.HashMap;
 import java.util.List;
 import java.util.Map;
 
 import org.apache.ranger.common.SearchField;
 import org.apache.ranger.entity.XXModuleDef;
 import org.apache.ranger.entity.XXPortalUser;
-import org.apache.ranger.entity.XXUser;
 import org.apache.ranger.entity.XXUserPermission;
 import org.apache.ranger.view.VXModuleDef;
 import org.apache.ranger.view.VXUserPermission;
@@ -70,25 +70,38 @@ public class XUserPermissionService extends XUserPermissionServiceBase<XXUserPer
 		return vObj;
 	}
 
-        public List<VXUserPermission> getPopulatedVXUserPermissionList(List<XXUserPermission> xuserPermissionList,Map<Long, XXUser> xXPortalUserIdXXUserMap,VXModuleDef vModuleDef){
-                List<VXUserPermission> vXUserPermissionList = new ArrayList<VXUserPermission>();
-                XXUser xXUser=null;
-                for(XXUserPermission xuserPermission:xuserPermissionList){
-                        if(xXPortalUserIdXXUserMap.containsKey(xuserPermission.getUserId())){
-                                xXUser =xXPortalUserIdXXUserMap.get(xuserPermission.getUserId());
-                                VXUserPermission vXUserPerm=new VXUserPermission();
-                                vXUserPerm.setId(xuserPermission.getId());
-                                vXUserPerm.setUserId(xXUser.getId());
-                                vXUserPerm.setModuleId(xuserPermission.getModuleId());
-                                vXUserPerm.setIsAllowed(xuserPermission.getIsAllowed());
-                                vXUserPerm.setCreateDate(xuserPermission.getCreateTime());
-                                vXUserPerm.setUpdateDate(xuserPermission.getUpdateTime());
-                                vXUserPerm.setModuleName(vModuleDef.getModule());
-                                vXUserPerm.setLoginId(xXUser.getName());
-                                vXUserPerm.setUserName(xXUser.getName());
-                                vXUserPermissionList.add(vXUserPerm);
-                        }
-                }
-                return vXUserPermissionList;
-        }
+	public List<VXUserPermission> getPopulatedVXUserPermissionList(List<XXUserPermission> xuserPermissionList,
+			Map<Long, Object[]> xXPortalUserIdXXUserMap, VXModuleDef vModuleDef) {
+		List<VXUserPermission> vXUserPermissionList = new ArrayList<VXUserPermission>();
+		Object[] xXUser = null;
+		for (XXUserPermission xuserPermission : xuserPermissionList) {
+			if (xXPortalUserIdXXUserMap.containsKey(xuserPermission.getUserId())) {
+				xXUser = xXPortalUserIdXXUserMap.get(xuserPermission.getUserId());
+				VXUserPermission vXUserPerm = new VXUserPermission();
+				vXUserPerm.setId(xuserPermission.getId());
+				vXUserPerm.setUserId((Long) xXUser[1]);
+				vXUserPerm.setModuleId(xuserPermission.getModuleId());
+				vXUserPerm.setIsAllowed(xuserPermission.getIsAllowed());
+				vXUserPerm.setCreateDate(xuserPermission.getCreateTime());
+				vXUserPerm.setUpdateDate(xuserPermission.getUpdateTime());
+				vXUserPerm.setModuleName(vModuleDef.getModule());
+				vXUserPerm.setLoginId((String) xXUser[2]);
+				vXUserPerm.setUserName((String) xXUser[2]);
+				vXUserPermissionList.add(vXUserPerm);
+			}
+		}
+		return vXUserPermissionList;
+	}
+
+	@Override
+	public Map<Long, VXUserPermission> convertVListToVMap(List<VXUserPermission> vObjList) {
+		Map<Long,VXUserPermission> ret = new HashMap<Long,VXUserPermission>();
+		if (vObjList == null) {
+			return ret;
+		}
+		for (VXUserPermission vObj : vObjList) {
+			ret.put(vObj.getUserId(), vObj);
+		}
+		return ret;
+	}
 }
\ No newline at end of file
