@@ -16,18 +16,12 @@
  */
 package org.apache.ranger.view;
 
-import javax.xml.bind.annotation.XmlAccessType;
-import javax.xml.bind.annotation.XmlAccessorType;
-import javax.xml.bind.annotation.XmlRootElement;
-
-import org.codehaus.jackson.annotate.JsonAutoDetect;
-import org.codehaus.jackson.annotate.JsonAutoDetect.Visibility;
-import org.codehaus.jackson.map.annotate.JsonSerialize;
+import com.fasterxml.jackson.annotation.JsonAutoDetect;
+import com.fasterxml.jackson.annotation.JsonAutoDetect.Visibility;
+import com.fasterxml.jackson.annotation.JsonInclude;
 
 @JsonAutoDetect(getterVisibility=Visibility.NONE, setterVisibility=Visibility.NONE, fieldVisibility=Visibility.ANY)
-@JsonSerialize(include=JsonSerialize.Inclusion.NON_NULL )
-@XmlRootElement
-@XmlAccessorType(XmlAccessType.FIELD)
+@JsonInclude(JsonInclude.Include.NON_NULL)
 public class VXMetricUserGroupCount implements java.io.Serializable {
 	private static final long serialVersionUID = 1L;
 	
@@ -126,4 +120,4 @@ public class VXMetricUserGroupCount implements java.io.Serializable {
                                 + ", userCountOfSysAdminAuditorRole=" + userCountOfSysAdminAuditorRole
                                 + ", userTotalCount=" + userTotalCount+ "]";
 	}
-}
\ No newline at end of file
+}
