@@ -34,10 +34,12 @@ define(function(require) {
             console.log("initialize a Controller Controller");
             if (App.userProfile && App.userProfile.get('configProperties') && App.userProfile.get('configProperties').inactivityTimeout
                 && App.userProfile.get('configProperties').inactivityTimeout > 0) {
-                XAUtil.setIdealActivityTime()
+                XAUtil.setIdleActivityTime()
                 $('#contentBody').on("click mousemove keyup mousedown scroll keypress", function(e){
                     // do preload here
-                    XAUtil.setIdealActivityTime()
+                    if ($('.stayLoggdedIn-popup').length == 0) {
+                        XAUtil.setIdleActivityTime()
+                    }
                 })
             }
             var vTopNav = require('views/common/TopNav');
@@ -126,6 +128,7 @@ define(function(require) {
             var VXAccessAuditList = require('collections/VXAccessAuditList');
             var RangerServiceDefList = require('collections/RangerServiceDefList');
             var serviceDefList = new RangerServiceDefList();
+            serviceDefList.setPageSize(XAGlobals.settings.MAX_PAGE_SIZE);
             serviceDefList.fetch({
                 cache : false,
                 async:false,
@@ -303,6 +306,7 @@ define(function(require) {
             var rangerZoneList = new RangerZoneList();
 
             var collection = new RangerServiceDefList();
+            collection.setPageSize(XAGlobals.settings.MAX_PAGE_SIZE);
             collection.queryParams.sortBy = 'serviceTypeId';
             if (type == 'tag') {
                 var tagServiceDef = new RangerServiceDef();
@@ -560,15 +564,19 @@ define(function(require) {
             var RangerZoneList = require('collections/RangerZoneList');
             var rangerServiceList = new RangerServiceList();
             var rangerZoneList = new RangerZoneList();
-            rangerServiceList.setPageSize(200);
+            rangerServiceList.setPageSize(XAGlobals.settings.MAX_PAGE_SIZE);
             rangerServiceList.fetch({
                 cache: false,
                 async: false
             });
+            rangerZoneList.setPageSize(XAGlobals.settings.MAX_PAGE_SIZE);
             rangerZoneList.fetch({
                 cache: false,
                 async: false,
             });
+            rangerZoneList.models = rangerZoneList.sortBy(function(model) {
+                return model.get('name').toLowerCase();
+            });
             App.rContent.show(new vSecurityZone({
                 rangerService: rangerServiceList,
                 collection: rangerZoneList,
@@ -586,7 +594,7 @@ define(function(require) {
             var RangerZoneList = require('collections/RangerZoneList');
             var zoneSerivesColl = new RangerZoneList();
             var rangerServiceList = new RangerServiceList();
-            rangerServiceList.setPageSize(200);
+            rangerServiceList.setPageSize(XAGlobals.settings.MAX_PAGE_SIZE);
             rangerServiceList.fetch({
                 cache: false,
             }).done(function() {
@@ -614,7 +622,7 @@ define(function(require) {
                 id: zoneId
             })
             var zoneSerivesColl = new RangerZoneList();
-            rangerServiceList.setPageSize(200);
+            rangerServiceList.setPageSize(XAGlobals.settings.MAX_PAGE_SIZE);
             rangerServiceList.fetch({
                 cache: false,
                 async: false,
