@@ -22,36 +22,43 @@ define(function(require) {
     'use strict';
     var Backbone = require('backbone');
     var App = require('App');
-
     var MAppState = require('models/VAppState');
     var XAGlobals = require('utils/XAGlobals');
+    var XAUtil    = require('utils/XAUtils');
+    var moment    = require('moment');
 
     return Backbone.Marionette.Controller.extend({
 
         initialize: function(options) {
-
             console.log("initialize a Controller Controller");
+            if (App.userProfile && App.userProfile.get('configProperties') && App.userProfile.get('configProperties').inactivityTimeout
+                && App.userProfile.get('configProperties').inactivityTimeout > 0) {
+                XAUtil.setIdleActivityTime()
+                $('#contentBody').on("click mousemove keyup mousedown scroll keypress", function(e){
+                    // do preload here
+                    if ($('.stayLoggdedIn-popup').length == 0) {
+                        XAUtil.setIdleActivityTime()
+                    }
+                })
+            }
             var vTopNav = require('views/common/TopNav');
             var vProfileBar = require('views/common/ProfileBar');
             var vFooter = require('views/common/Footer');
             var rSidebar = require('views/policymanager/ServiceLayoutSidebar');
-
             App.rTopNav.show(new vTopNav({
                 model: App.userProfile,
                 appState: MAppState
             }));
             var type = "resource"
-
             $('#r_sidebar').addClass('sidebar-list')
             App.rSideBar.show(new rSidebar({
                 type: type,
             }))
-
             App.rTopProfileBar.show(new vProfileBar({}));
-
             App.rFooter.show(new vFooter({}));
-
             $('#contentBody').addClass("service-layout");
+            App.rSideBar.$el.addClass('expanded');
+            App.rSideBar.$el.removeClass('collapsed');
         },
 
         dashboardAction: function(action) {
@@ -60,7 +67,6 @@ define(function(require) {
             MAppState.set({
                 'currentTab': XAGlobals.AppTabs.Dashboard.value
             });
-
             App.rContent.show(new vDashboardLayout({}));
         },
 
@@ -119,6 +125,32 @@ define(function(require) {
                 }));
             });
         },
+        auditEventDetail: function(eventID) {
+            MAppState.set({
+                'currentTab': XAGlobals.AppTabs.AccessManager.value
+            });
+            var view = require('views/reports/AuditAccessLogDetailView');
+            var VXAccessAuditList = require('collections/VXAccessAuditList');
+            var RangerServiceDefList = require('collections/RangerServiceDefList');
+            var serviceDefList = new RangerServiceDefList();
+            serviceDefList.fetch({
+                cache : false,
+                async:false,
+                data :{'pageSource':'Audit'}
+            });
+            var auditList = new VXAccessAuditList();
+            auditList.url = 'service/assets/accessAudit?eventId='+eventID
+            auditList.fetch({
+               cache : false,
+               async : false
+            }).done(function() {
+                App.rContent.show(new view({
+                    auditaccessDetail : auditList.models[0].attributes,
+                    auditAccessView : true,
+                    serviceDefList : serviceDefList
+                }));
+            })
+        },
         //************** UserProfile Related *********************/
         userProfileAction: function() {
             MAppState.set({
@@ -156,7 +188,6 @@ define(function(require) {
             var VXUser = require('models/VXUser');
             var VXUserList = require('collections/VXUserList');
             var VXGroupList = require('collections/VXGroupList');
-
             var groupList = new VXGroupList();
             var user = new VXUser();
             this.rSidebarContentHideAndShow('UserGroupRoleManager');
@@ -178,7 +209,6 @@ define(function(require) {
             var view = require('views/users/UserCreate');
             var VXUser = require('models/VXUser');
             var VXUserList = require('collections/VXUserList');
-
             var user = new VXUser({
                 id: userId
             });
@@ -199,7 +229,6 @@ define(function(require) {
             var view = require('views/users/GroupCreate');
             var VXGroup = require('models/VXGroup');
             var VXGroupList = require('collections/VXGroupList');
-
             var group = new VXGroup();
             this.rSidebarContentHideAndShow('UserGroupRoleManager');
             group.collection = new VXGroupList();
@@ -214,13 +243,11 @@ define(function(require) {
             var view = require('views/users/GroupCreate');
             var VXGroup = require('models/VXGroup');
             var VXGroupList = require('collections/VXGroupList');
-
             var group = new VXGroup({
                 id: groupId
             });
             this.rSidebarContentHideAndShow('UserGroupRoleManager');
             group.collection = new VXGroupList();
-
             group.fetch({
                 cache: true
             }).done(function() {
@@ -237,7 +264,6 @@ define(function(require) {
             var view = require('views/users/RoleCreate');
             var VXRole = require('models/VXRole');
             var VXRoleList = require('collections/VXRoleList');
-
             var role = new VXRole();
             this.rSidebarContentHideAndShow('UserGroupRoleManager');
             role.collection = new VXRoleList();
@@ -258,7 +284,6 @@ define(function(require) {
             });
             this.rSidebarContentHideAndShow('UserGroupRoleManager');
             role.collection = new VXRoleList();
-
             role.fetch({
                 cache: true
             }).done(function() {
@@ -313,7 +338,6 @@ define(function(require) {
             var RangerServiceDef = require('models/RangerServiceDef');
             var RangerService = require('models/RangerService');
             var XAUtil = require('utils/XAUtils');
-
             var rangerServiceDefModel = new RangerServiceDef({
                 id: serviceTypeId
             });
@@ -344,11 +368,9 @@ define(function(require) {
             var view = require('views/policies/NRangerPolicyTableLayout');
             var RangerService = require('models/RangerService');
             var RangerPolicyList = require('collections/RangerPolicyList');
-
             var rangerPolicyList = new RangerPolicyList();
             this.rSidebarContentHideAndShow('AccessManager');
             App.rSideBar.currentView.selecttedService(serviceId);
-            
             rangerPolicyList.queryParams['policyType'] = policyType.split("?")[0];
             if (_.isNaN(parseInt(serviceId))) {
                 var rangerService = new RangerService();
@@ -402,13 +424,11 @@ define(function(require) {
             MAppState.set({
                 'currentTab': XAGlobals.AppTabs.AccessManager.value
             });
-
             var view = require('views/policies/RangerPolicyCreate');
             var RangerService = require('models/RangerService');
             var RangerPolicy = require('models/RangerPolicy');
             var RangerPolicyList = require('collections/RangerPolicyList');
             var XAUtil = require('utils/XAUtils');
-
             var rangerPolicy = new RangerPolicy({
                 id: policyId
             });
@@ -523,6 +543,7 @@ define(function(require) {
             var RangerZoneList = require('collections/RangerZoneList');
             var rangerServiceList = new RangerServiceList();
             var rangerZoneList = new RangerZoneList();
+            rangerServiceList.setPageSize(200);
             rangerServiceList.fetch({
                 cache: false,
                 async: false
@@ -531,6 +552,9 @@ define(function(require) {
                 cache: false,
                 async: false,
             });
+            rangerZoneList.models = rangerZoneList.sortBy(function(model) {
+                return model.get('name').toLowerCase();
+            });
             if (App.rSideBar.currentView) {
                 this.rSidebarContentHideAndShow('SecurityZone');
                 if (!_.isNaN(parseInt(listId))) {
@@ -564,6 +588,7 @@ define(function(require) {
             var zoneSerivesColl = new RangerZoneList();
             var rangerServiceList = new RangerServiceList();
             this.rSidebarContentHideAndShow('SecurityZone');
+            rangerServiceList.setPageSize(200);
             rangerServiceList.fetch({
                 cache: false,
             }).done(function() {
@@ -592,6 +617,7 @@ define(function(require) {
             })
             var zoneSerivesColl = new RangerZoneList();
             this.rSidebarContentHideAndShow('SecurityZone');
+            rangerServiceList.setPageSize(200);
             rangerServiceList.fetch({
                 cache: false,
                 async: false,
