@@ -23,10 +23,10 @@ import static org.junit.Assert.assertEquals;
 import javax.ws.rs.WebApplicationException;
 import javax.ws.rs.core.Response;
 
-import org.apache.ranger.audit.dao.DaoManager;
 import org.apache.ranger.biz.RangerBizUtil;
 import org.apache.ranger.biz.SessionMgr;
 import org.apache.ranger.biz.XUserMgr;
+import org.apache.ranger.common.ContextUtil;
 import org.apache.ranger.common.MessageEnums;
 import org.apache.ranger.common.RESTErrorUtil;
 import org.apache.ranger.common.SearchCriteria;
@@ -35,6 +35,7 @@ import org.apache.ranger.common.SortField;
 import org.apache.ranger.common.AppConstants;
 import org.apache.ranger.common.RangerConstants;
 import org.apache.ranger.common.StringUtil;
+import org.apache.ranger.common.UserSessionBase;
 import org.apache.ranger.db.RangerDaoManager;
 import org.apache.ranger.db.XXGroupDao;
 import org.apache.ranger.entity.XXResource;
@@ -42,6 +43,8 @@ import org.apache.ranger.plugin.model.RangerPolicy;
 import org.apache.ranger.plugin.model.RangerPolicy.RangerPolicyItem;
 import org.apache.ranger.plugin.model.RangerPolicy.RangerDataMaskPolicyItem;
 import org.apache.ranger.plugin.model.RangerPolicy.RangerRowFilterPolicyItem;
+import org.apache.ranger.security.context.RangerContextHolder;
+import org.apache.ranger.security.context.RangerSecurityContext;
 import org.apache.ranger.service.AuthSessionService;
 import org.apache.ranger.service.XGroupGroupService;
 import org.apache.ranger.service.XGroupPermissionService;
@@ -56,8 +59,6 @@ import org.apache.ranger.view.VXAuditMapList;
 import org.apache.ranger.view.VXAuthSession;
 import org.apache.ranger.view.VXAuthSessionList;
 import org.apache.ranger.view.VXGroup;
-import org.apache.ranger.view.VXGroupGroup;
-import org.apache.ranger.view.VXGroupGroupList;
 import org.apache.ranger.view.VXGroupList;
 import org.apache.ranger.view.VXGroupPermission;
 import org.apache.ranger.view.VXGroupPermissionList;
@@ -84,7 +85,9 @@ import org.apache.ranger.entity.XXAsset;
 import org.apache.ranger.entity.XXGroupGroup;
 import org.apache.ranger.entity.XXGroupPermission;
 import org.apache.ranger.entity.XXPermMap;
+import org.apache.ranger.entity.XXPortalUser;
 import org.apache.ranger.service.XPermMapService;
+import org.junit.After;
 import org.junit.FixMethodOrder;
 import org.junit.Rule;
 import org.junit.Test;
@@ -131,6 +134,7 @@ public class TestXUserREST {
 	@Mock SearchCriteria searchCriteria;
 	@Mock XGroupService xGroupService;
 	@Mock SearchUtil searchUtil;
+	@Mock StringUtil stringUtil;
 	@Mock VXLong vXLong;
 	@Mock HttpServletRequest request;
 	@Mock VXUser vXUser1;
@@ -141,8 +145,6 @@ public class TestXUserREST {
 	@Mock VXGroupUser vXGroupUser;
 	@Mock XGroupUserService xGroupUserService;
 	@Mock VXGroupUserList vXGroupUserList;
-	@Mock VXGroupGroup vXGroupGroup;
-	@Mock VXGroupGroupList vXGroupGroupList;
 	@Mock XGroupGroupService xGroupGroupService;
 	@Mock VXPermMap vXPermMap;
 	@Mock RESTErrorUtil restErrorUtil;
@@ -156,7 +158,6 @@ public class TestXUserREST {
 	@Mock XXResource xXResource;
 	@Mock XXAuditMap XXAuditMap;
 	@Mock XAuditMapService xAuditMapService;
-	@Mock DaoManager daoManager;
 	@Mock XPermMapService xPermMapService;
 	@Mock XXAsset XXAsset;
 	@Mock RangerDaoManager rangerDaoManager;
@@ -327,7 +328,7 @@ public class TestXUserREST {
 	
 		Mockito.when(searchUtil.extractString(request, testSearchCriteria, "name", "group name", null)).thenReturn("");
 		Mockito.when(searchUtil.extractInt(request, testSearchCriteria, "isVisible", "Group Visibility")).thenReturn(1);
-		Mockito.when(searchUtil.extractString(request, testSearchCriteria, "groupSource", "group source", null)).thenReturn("");
+		Mockito.when(searchUtil.extractInt(request, testSearchCriteria, "groupSource", "group source")).thenReturn(1);
 		VXGroupList testvXGroupList=createxGroupList();
 		Mockito.when(xUserMgr.searchXGroups(testSearchCriteria)).thenReturn(testvXGroupList);
 		VXGroupList outputvXGroupList=xUserRest.searchXGroups(request);
@@ -336,7 +337,7 @@ public class TestXUserREST {
 		Mockito.verify(searchUtil).extractCommonCriterias((HttpServletRequest)Mockito.any() ,(List<SortField>)Mockito.any());
 		Mockito.verify(searchUtil).extractString(request, testSearchCriteria, "name", "group name", null);
 		Mockito.verify(searchUtil).extractInt(request, testSearchCriteria, "isVisible", "Group Visibility");
-		Mockito.verify(searchUtil).extractString(request, testSearchCriteria, "groupSource", "group source", null);
+		Mockito.verify(searchUtil).extractInt(request, testSearchCriteria, "groupSource", "group source");
 		assertNotNull(outputvXGroupList);
 		assertEquals(outputvXGroupList.getTotalCount(),testvXGroupList.getTotalCount());
 		assertEquals(outputvXGroupList.getClass(),testvXGroupList.getClass());
@@ -506,7 +507,7 @@ public class TestXUserREST {
 		Mockito.when(searchUtil.extractInt(request, testSearchCriteria, "isVisible", "User Visibility")).thenReturn(1);
 		Mockito.when(searchUtil.extractInt(request, testSearchCriteria, "status", "User Status")).thenReturn(1);
 		Mockito.when(searchUtil.extractStringList(request, testSearchCriteria, "userRoleList", "User Role List", "userRoleList", null,null)).thenReturn(new ArrayList<String>());
-		Mockito.when(searchUtil.extractString(request, testSearchCriteria, "userRole", "UserRole", null)).thenReturn("");
+		Mockito.when(searchUtil.extractRoleString(request, testSearchCriteria, "userRole", "Role", null)).thenReturn("");
 		
 		List<VXUser> vXUsersList= new ArrayList<VXUser>();
 		vXUsersList.add(vxUser);
@@ -514,7 +515,7 @@ public class TestXUserREST {
 		testVXUserList.setVXUsers(vXUsersList);
 		
 		Mockito.when(xUserMgr.searchXUsers(testSearchCriteria)).thenReturn(testVXUserList);
-		VXUserList gotVXUserList=xUserRest.searchXUsers(request);
+		VXUserList gotVXUserList=xUserRest.searchXUsers(request, null, null);
 		
 		Mockito.verify(xUserMgr).searchXUsers(testSearchCriteria);
 		Mockito.verify(searchUtil).extractCommonCriterias((HttpServletRequest)Mockito.any() ,(List<SortField>)Mockito.any());
@@ -525,11 +526,14 @@ public class TestXUserREST {
 		Mockito.verify(searchUtil).extractInt(request, testSearchCriteria, "isVisible", "User Visibility");
 		Mockito.verify(searchUtil).extractInt(request, testSearchCriteria, "status", "User Status");
 		Mockito.verify(searchUtil).extractStringList(request, testSearchCriteria, "userRoleList", "User Role List", "userRoleList", null,null);
-		Mockito.verify(searchUtil).extractString(request, testSearchCriteria, "userRole", "UserRole", null);
+		Mockito.verify(searchUtil).extractRoleString(request, testSearchCriteria, "userRole", "Role", null);
 		assertNotNull(gotVXUserList);
 		assertEquals(testVXUserList.getTotalCount(),gotVXUserList.getTotalCount());
 		assertEquals(testVXUserList.getClass(),gotVXUserList.getClass());
 	}
+	
+	
+	
 	@SuppressWarnings("unchecked")
 	@Test
 	public void test25countXUsers() {
@@ -639,92 +643,6 @@ public class TestXUserREST {
 		assertEquals(testvxLong.getClass(),vXLong.getClass());
 	}
 	@Test
-	public void test32getXGroupGroup() {
-		VXGroupGroup compareTestVXGroup=createVXGroupGroup();
-		
-		Mockito.when(xUserMgr.getXGroupGroup(id)).thenReturn(compareTestVXGroup);
-		VXGroupGroup retVxGroup= xUserRest.getXGroupGroup(id);
-		
-		assertNotNull(retVxGroup);
-		assertEquals(compareTestVXGroup.getClass(),retVxGroup.getClass());
-		assertEquals(compareTestVXGroup.getId(),retVxGroup.getId());
-		Mockito.verify(xUserMgr).getXGroupGroup(id);
-	}	@Test
-	public void test33createXGroupGroup() {
-		VXGroupGroup compareTestVXGroup=createVXGroupGroup();
-		 
-		Mockito.when(xUserMgr.createXGroupGroup(compareTestVXGroup)).thenReturn(compareTestVXGroup);
-		VXGroupGroup retVxGroup= xUserRest.createXGroupGroup(compareTestVXGroup);
-			
-		assertNotNull(retVxGroup);
-		assertEquals(compareTestVXGroup.getClass(),retVxGroup.getClass());
-		assertEquals(compareTestVXGroup.getId(),retVxGroup.getId());
-		Mockito.verify(xUserMgr).createXGroupGroup(compareTestVXGroup);
-	}
-	@Test
-	public void test34updateXGroupGroup() {
-		VXGroupGroup compareTestVXGroup=createVXGroupGroup();
-		 
-		Mockito.when(xUserMgr.updateXGroupGroup(compareTestVXGroup)).thenReturn(compareTestVXGroup);
-		VXGroupGroup retVxGroup= xUserRest.updateXGroupGroup(compareTestVXGroup);
-			
-		assertNotNull(retVxGroup);
-		assertEquals(compareTestVXGroup.getClass(),retVxGroup.getClass());
-		assertEquals(compareTestVXGroup.getId(),retVxGroup.getId());
-		Mockito.verify(xUserMgr).updateXGroupGroup(compareTestVXGroup);
-	}
-	@Test
-	public void test35deleteXGroupGroup() {
-		boolean forceDelete = false;
-		
-		Mockito.doNothing().when(xUserMgr).deleteXGroupGroup(id, forceDelete);
-		xUserRest.deleteXGroupGroup(id,request);
-		Mockito.verify(xUserMgr).deleteXGroupGroup(id,forceDelete);
-	}
-	@SuppressWarnings("unchecked")
-	@Test
-	public void test36searchXGroupGroups() {
-		VXGroupGroupList testvXGroupGroupList=new VXGroupGroupList();
-		VXGroupGroup testVXGroup=createVXGroupGroup();
-		List<VXGroupGroup> testVXGroupGroups= new ArrayList<VXGroupGroup>();
-		testVXGroupGroups.add(testVXGroup);
-		testvXGroupGroupList.setVXGroupGroups(testVXGroupGroups);
-		
-		HttpServletRequest request = Mockito.mock(HttpServletRequest.class);
-		SearchCriteria testSearchCriteria=createsearchCriteria();
-		
-		Mockito.when(searchUtil.extractCommonCriterias((HttpServletRequest)Mockito.any() ,(List<SortField>)Mockito.any())).thenReturn(testSearchCriteria);
-
-		Mockito.when(xUserMgr.searchXGroupGroups(testSearchCriteria)).thenReturn(testvXGroupGroupList);
-		VXGroupGroupList outputvXGroupGroupList=xUserRest.searchXGroupGroups(request);
-		
-		Mockito.verify(xUserMgr).searchXGroupGroups(testSearchCriteria);
-		Mockito.verify(searchUtil).extractCommonCriterias((HttpServletRequest)Mockito.any() ,(List<SortField>)Mockito.any());
-		
-		assertNotNull(outputvXGroupGroupList);
-		assertEquals(outputvXGroupGroupList.getClass(),testvXGroupGroupList.getClass());
-		assertEquals(outputvXGroupGroupList.getResultSize(),testvXGroupGroupList.getResultSize());
-	}
-	@SuppressWarnings("unchecked")
-	@Test
-	public void test37countXGroupGroups() {
-		HttpServletRequest request = Mockito.mock(HttpServletRequest.class);
-		SearchCriteria testSearchCriteria=createsearchCriteria();
-				
-		Mockito.when(searchUtil.extractCommonCriterias((HttpServletRequest)Mockito.any() ,(List<SortField>)Mockito.any())).thenReturn(testSearchCriteria);
-		
-		vXLong.setValue(1);
-			
-		Mockito.when(xUserMgr.getXGroupGroupSearchCount(testSearchCriteria)).thenReturn(vXLong);
-		VXLong testvxLong=xUserRest.countXGroupGroups(request);
-		Mockito.verify(xUserMgr).getXGroupGroupSearchCount(testSearchCriteria);
-		Mockito.verify(searchUtil).extractCommonCriterias((HttpServletRequest)Mockito.any() ,(List<SortField>)Mockito.any());
-			
-		assertNotNull(testvxLong);
-		assertEquals(testvxLong.getClass(),vXLong.getClass());
-		assertEquals(testvxLong.getValue(),vXLong.getValue());
-	}
-	@Test
 	public void test38getXPermMapVXResourceNull() throws Exception{
 		VXPermMap permMap = testcreateXPermMap();
 		
@@ -1588,18 +1506,17 @@ public class TestXUserREST {
 	}
 	@Test
 	public void test90updateXGroupPermission() {
-	
+
 		VXGroupPermission testVXGroupPermission = createVXGroupPermission();
 		Mockito.doNothing().when(xUserMgr).checkAdminAccess();
 		Mockito.when(xUserMgr.updateXGroupPermission(testVXGroupPermission)).thenReturn(testVXGroupPermission);
-		VXGroupPermission retVXGroupPermission=xUserRest.updateXGroupPermission(testVXGroupPermission);
+		VXGroupPermission retVXGroupPermission=xUserRest.updateXGroupPermission(testVXGroupPermission.getId(), testVXGroupPermission);
 		Mockito.verify(xUserMgr).updateXGroupPermission(testVXGroupPermission);
 		Mockito.verify(xUserMgr).checkAdminAccess();
 		assertNotNull(retVXGroupPermission);
 		assertEquals(retVXGroupPermission.getId(), testVXGroupPermission.getId());
 		assertEquals(retVXGroupPermission.getClass(), testVXGroupPermission.getClass());
-	
-		
+
 	}
 	@Test
 	public void test91deleteXGroupPermission() {
@@ -1970,6 +1887,143 @@ public class TestXUserREST {
 		
 	}
 	
+	@SuppressWarnings({ "unchecked", "static-access" })
+	@Test
+	public void test113ErrorWhenRoleUserIsTryingToFetchAnotherUserDetails() {
+	
+		destroySession();
+		String userLoginID = "testuser";
+		Long userId = 8L;
+		
+		RangerSecurityContext context = new RangerSecurityContext();
+		context.setUserSession(new UserSessionBase());
+		RangerContextHolder.setSecurityContext(context);
+		UserSessionBase currentUserSession = ContextUtil.getCurrentUserSession();
+		currentUserSession.setUserAdmin(false);
+		XXPortalUser xXPortalUser = new XXPortalUser();
+		xXPortalUser.setLoginId(userLoginID);
+		xXPortalUser.setId(userId);
+		currentUserSession.setXXPortalUser(xXPortalUser);
+		
+		VXUser loggedInUser = createVXUser();
+		List<String> loggedInUserRole = new ArrayList<String>();
+		loggedInUserRole.add(RangerConstants.ROLE_USER);
+		loggedInUser.setId(8L);
+		loggedInUser.setName("testuser");
+		loggedInUser.setUserRoleList(loggedInUserRole);
+		
+		HttpServletRequest request = Mockito.mock(HttpServletRequest.class);
+		SearchCriteria testSearchCriteria=createsearchCriteria();
+		testSearchCriteria.addParam("name", "admin");
+		
+		Mockito.when(searchUtil.extractCommonCriterias((HttpServletRequest)Mockito.any(), (List<SortField>)Mockito.any())).thenReturn(testSearchCriteria);
+		
+		Mockito.when(searchUtil.extractCommonCriterias(request, xUserService.sortFields)).thenReturn(testSearchCriteria);
+		Mockito.when(searchUtil.extractString(request, testSearchCriteria, "emailAddress", "Email Address",null)).thenReturn("");
+		Mockito.when(searchUtil.extractInt(request, testSearchCriteria, "userSource", "User Source")).thenReturn(1);
+		Mockito.when(searchUtil.extractInt(request, testSearchCriteria, "isVisible", "User Visibility")).thenReturn(1);
+		Mockito.when(searchUtil.extractInt(request, testSearchCriteria, "status", "User Status")).thenReturn(1);
+		Mockito.when(searchUtil.extractStringList(request, testSearchCriteria, "userRoleList", "User Role List", "userRoleList", null,null)).thenReturn(new ArrayList<String>());
+		Mockito.when(searchUtil.extractRoleString(request, testSearchCriteria, "userRole", "Role", null)).thenReturn("");
+		Mockito.when(xUserService.getXUserByUserName("testuser")).thenReturn(loggedInUser);
+		Mockito.when(restErrorUtil.create403RESTException("Logged-In user is not allowed to access requested user data.")).thenThrow(new WebApplicationException());
+		thrown.expect(WebApplicationException.class);
+		
+		xUserRest.searchXUsers(request, null, null);
+	}
+
+	@SuppressWarnings({ "unchecked", "static-access" })
+	@Test
+	public void test114RoleUserWillGetOnlyHisOwnUserDetails() {
+	
+		destroySession();
+		String userLoginID = "testuser";
+		Long userId = 8L;
+		
+		RangerSecurityContext context = new RangerSecurityContext();
+		context.setUserSession(new UserSessionBase());
+		RangerContextHolder.setSecurityContext(context);
+		UserSessionBase currentUserSession = ContextUtil.getCurrentUserSession();
+		currentUserSession.setUserAdmin(false);
+		XXPortalUser xXPortalUser = new XXPortalUser();
+		xXPortalUser.setLoginId(userLoginID);
+		xXPortalUser.setId(userId);
+		currentUserSession.setXXPortalUser(xXPortalUser);
+		
+		VXUser loggedInUser = createVXUser();
+		List<String> loggedInUserRole = new ArrayList<String>();
+		loggedInUserRole.add(RangerConstants.ROLE_USER);
+		loggedInUser.setId(8L);
+		loggedInUser.setName("testuser");
+		loggedInUser.setUserRoleList(loggedInUserRole);
+		
+		VXUserList expecteUserList = new VXUserList();
+		VXUser expectedUser = new VXUser();
+		expectedUser.setId(8L);
+		expectedUser.setName("testuser");
+		List<VXUser> userList = new ArrayList<VXUser>();
+		userList.add(expectedUser);
+		expecteUserList.setVXUsers(userList);
+		
+		HttpServletRequest request = Mockito.mock(HttpServletRequest.class);
+		SearchCriteria testSearchCriteria=createsearchCriteria();
+		
+		Mockito.when(searchUtil.extractCommonCriterias((HttpServletRequest)Mockito.any(), (List<SortField>)Mockito.any())).thenReturn(testSearchCriteria);
+		
+		Mockito.when(searchUtil.extractCommonCriterias(request, xUserService.sortFields)).thenReturn(testSearchCriteria);
+		Mockito.when(searchUtil.extractString(request, testSearchCriteria, "emailAddress", "Email Address",null)).thenReturn("");
+		Mockito.when(searchUtil.extractInt(request, testSearchCriteria, "userSource", "User Source")).thenReturn(1);
+		Mockito.when(searchUtil.extractInt(request, testSearchCriteria, "isVisible", "User Visibility")).thenReturn(1);
+		Mockito.when(searchUtil.extractInt(request, testSearchCriteria, "status", "User Status")).thenReturn(1);
+		Mockito.when(searchUtil.extractStringList(request, testSearchCriteria, "userRoleList", "User Role List", "userRoleList", null,null)).thenReturn(new ArrayList<String>());
+		Mockito.when(searchUtil.extractRoleString(request, testSearchCriteria, "userRole", "Role", null)).thenReturn("");
+		Mockito.when(xUserService.getXUserByUserName("testuser")).thenReturn(loggedInUser);
+		Mockito.when(xUserMgr.searchXUsers(testSearchCriteria)).thenReturn(expecteUserList);
+		VXUserList gotVXUserList=xUserRest.searchXUsers(request, null, null);
+		
+		assertEquals(gotVXUserList.getList().size(), 1);
+		assertEquals(gotVXUserList.getList().get(0).getId(), expectedUser.getId());
+		assertEquals(gotVXUserList.getList().get(0).getName(), expectedUser.getName());
+	}
+
+	@Test
+	public void test115updateXGroupPermissionWithInvalidPermissionId() {
+
+		VXGroupPermission testVXGroupPermission = createVXGroupPermission();
+		Mockito.when(restErrorUtil.createRESTException(Mockito.anyInt(), Mockito.anyString(), Mockito.anyBoolean())).thenThrow(new WebApplicationException());
+		thrown.expect(WebApplicationException.class);
+		VXGroupPermission retVXGroupPermission=xUserRest.updateXGroupPermission(-1L, testVXGroupPermission);
+		Mockito.verify(xUserMgr).updateXGroupPermission(testVXGroupPermission);
+		Mockito.verify(xUserMgr).checkAdminAccess();
+		assertNotNull(retVXGroupPermission);
+		assertEquals(retVXGroupPermission.getId(), testVXGroupPermission.getId());
+		assertEquals(retVXGroupPermission.getClass(), testVXGroupPermission.getClass());
+
+	}
+
+	@Test
+	public void test116updateXGroupPermissionWithPermissionIdIsNull() {
+
+		VXGroupPermission testVXGroupPermission = createVXGroupPermission();
+		Long testVXGroupPermissionId = testVXGroupPermission.getId();
+		testVXGroupPermission.setId(null);
+		Mockito.doNothing().when(xUserMgr).checkAdminAccess();
+		Mockito.when(xUserMgr.updateXGroupPermission(testVXGroupPermission)).thenReturn(testVXGroupPermission);
+		VXGroupPermission retVXGroupPermission=xUserRest.updateXGroupPermission(testVXGroupPermissionId, testVXGroupPermission);
+		Mockito.verify(xUserMgr).updateXGroupPermission(testVXGroupPermission);
+		Mockito.verify(xUserMgr).checkAdminAccess();
+		assertNotNull(retVXGroupPermission);
+		assertEquals(retVXGroupPermission.getId(), testVXGroupPermission.getId());
+		assertEquals(retVXGroupPermission.getClass(), testVXGroupPermission.getClass());
+
+	}
+	
+	@After
+	public void destroySession() {
+		RangerSecurityContext context = new RangerSecurityContext();
+		context.setUserSession(null);
+		RangerContextHolder.setSecurityContext(context);
+	}
 	
 	private HashMap<Long, Integer> creategroupVisibilityMap()
 	{
@@ -2037,17 +2091,7 @@ public class TestXUserREST {
 		testVXGroupUser.setUserId(id);
 		return testVXGroupUser;
 	}
-	private VXGroupGroup createVXGroupGroup() {
-		VXGroupGroup testVXGroupGroup= new VXGroupGroup();
-		testVXGroupGroup.setName("testGroup");
-		testVXGroupGroup.setCreateDate(new Date());
-		testVXGroupGroup.setUpdateDate(new Date());
-		testVXGroupGroup.setUpdatedBy("Admin");
-		testVXGroupGroup.setOwner("Admin");
-		testVXGroupGroup.setId(id);
-		testVXGroupGroup.setParentGroupId(id);
-		return testVXGroupGroup;
-	}
+
 	private VXPermMap testcreateXPermMap(){
 		VXPermMap testVXPermMap= new VXPermMap();
 		testVXPermMap.setCreateDate(new Date());
