@@ -22,6 +22,7 @@ package org.apache.ranger.tagsync.process;
 import org.apache.commons.lang.StringUtils;
 import org.apache.hadoop.conf.Configuration;
 import org.apache.hadoop.security.SecureClientLogin;
+import org.apache.ranger.tagsync.ha.TagSyncHAInitializerImpl;
 import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
 
@@ -43,6 +44,7 @@ import org.apache.ranger.plugin.util.RangerCommonConstants;
 public class TagSyncConfig extends Configuration {
 	private static final Logger LOG = LoggerFactory.getLogger(TagSyncConfig.class);
 
+	private static TagSyncConfig instance = null;
 	private static final String CONFIG_FILE = "ranger-tagsync-site.xml";
 
 	private static final String DEFAULT_CONFIG_FILE = "ranger-tagsync-default.xml";
@@ -97,6 +99,7 @@ public class TagSyncConfig extends Configuration {
 
 	private static final int DEFAULT_TAGSYNC_TAGADMIN_CONNECTION_CHECK_INTERVAL = 15000;
 	private static final long DEFAULT_TAGSYNC_ATLASREST_SOURCE_DOWNLOAD_INTERVAL = 900000;
+	public  static final int  DEFAULT_TAGSYNC_ATLASREST_SOURCE_ENTITIES_BATCH_SIZE = 10000;
 	private static final long DEFAULT_TAGSYNC_FILESOURCE_MOD_TIME_CHECK_INTERVAL = 60000;
 	private static final long DEFAULT_TAGSYNC_SOURCE_RETRY_INITIALIZATION_INTERVAL = 10000;
 
@@ -120,8 +123,8 @@ public class TagSyncConfig extends Configuration {
 	private static final int     DEFAULT_TAGSYNC_SINK_MAX_BATCH_SIZE = 1;
 	private static final String  TAGSYNC_SINK_MAX_BATCH_SIZE_PROP    = "ranger.tagsync.dest.ranger.max.batch.size";
 
-
-
+	private static final String TAGSYNC_ATLASREST_SOURCE_ENTITIES_BATCH_SIZE = "ranger.tagsync.source.atlasrest.entities.batch.size";
+	public static final String TAGSYNC_SERVER_HA_ENABLED_PARAM = "ranger-tagsync.server.ha.enabled";
 
 	private Properties props;
 
@@ -134,7 +137,14 @@ public class TagSyncConfig extends Configuration {
 	}
 	
 	public static TagSyncConfig getInstance() {
-		return new TagSyncConfig();
+		if(instance == null ){
+			synchronized (TagSyncConfig.class){
+				if(instance == null ){
+					instance = new TagSyncConfig();
+				}
+			}
+		}
+		return instance;
 	}
 
 	public Properties getProperties() {
@@ -214,6 +224,10 @@ public class TagSyncConfig extends Configuration {
 		return ret;
 	}
 
+	synchronized static public boolean isTagSyncServiceActive() {
+		return TagSyncHAInitializerImpl.getInstance(TagSyncConfig.getInstance()).isActive();
+	}
+
 	@Override
 	public String toString() {
 		StringBuilder sb = new StringBuilder();
@@ -540,4 +554,18 @@ public class TagSyncConfig extends Configuration {
 		return "true".equalsIgnoreCase(StringUtils.trimToEmpty(val));
 	}
 
+	static public int getAtlasRestSourceEntitiesBatchSize(Properties prop) {
+		String val = prop.getProperty(TAGSYNC_ATLASREST_SOURCE_ENTITIES_BATCH_SIZE);
+		int    ret = DEFAULT_TAGSYNC_ATLASREST_SOURCE_ENTITIES_BATCH_SIZE;
+
+		if (StringUtils.isNotBlank(val)) {
+			try {
+				ret = Integer.valueOf(val);
+			} catch (NumberFormatException exception) {
+				// Ignore
+			}
+		}
+
+		return ret;
+	}
 }
